@@ -39,10 +39,6 @@ class FetchSource(Function):
         ),
     ]
 
-    @classmethod
-    def call(cls, **kwargs):
-        return cls.default_call(**kwargs)
-
 
 def functions():
     return FetchSource.defn()
