@@ -34,10 +34,6 @@ class RestoreInstanceProfile(Function):
         ),
     ]
 
-    @classmethod
-    def call(cls, **kwargs):
-        return cls.default_call(**kwargs)
-
 
 def functions():
     return RestoreInstanceProfile.defn()
