@@ -22,10 +22,6 @@ class RunSimpleHTTPServer(Function):
         ),
     ]
 
-    @classmethod
-    def call(cls, **kwargs):
-        return cls.default_call(**kwargs)
-
 
 def functions():
     return RunSimpleHTTPServer.defn()
