@@ -14,10 +14,6 @@ class StopMongoOrchestration(Function):
         ),
     ]
 
-    @classmethod
-    def call(cls, **kwargs):
-        return cls.default_call(**kwargs)
-
 
 def functions():
     return StopMongoOrchestration.defn()
