@@ -19,10 +19,6 @@ class UploadTestResults(Function):
         ),
     ]
 
-    @classmethod
-    def call(cls, **kwargs):
-        return cls.default_call(**kwargs)
-
 
 def functions():
     return UploadTestResults.defn()
