@@ -16,10 +16,6 @@ class KmsDivergenceCheck(Function):
         ),
     ]
 
-    @classmethod
-    def call(cls, **kwargs):
-        return cls.default_call(**kwargs)
-
 
 def functions():
     return KmsDivergenceCheck.defn()
