@@ -38,10 +38,6 @@ class ScanBuild(Function):
         ),
     ]
 
-    @classmethod
-    def call(cls, **kwargs):
-        return cls.default_call(**kwargs)
-
 
 def functions():
     return ScanBuild.defn()
