@@ -35,7 +35,3 @@ class CompileCommon(Function):
                 },
             ),
         ]
-
-    @classmethod
-    def call(cls, **kwargs):
-        return cls.default_call(**kwargs)
