@@ -28,8 +28,6 @@ class Distro(BaseModel):
         '2019',
         '2022',
         'vsCurrent',
-        'vsCurrent2',
-        'vsMulti',
     ] | None = None
     size: Literal['small', 'large'] | None = None
     arch: Literal['arm64', 'power', 'zseries'] | None = None
@@ -37,7 +35,7 @@ class Distro(BaseModel):
     @validator('os_ver')
     @classmethod
     def validate_os_ver(cls, value):
-        return Version(value)
+        return value == 'latest' or Version(value)
 
 
 def ls_distro(name, **kwargs):
@@ -48,9 +46,8 @@ def ls_distro(name, **kwargs):
 
 
 DEBIAN_DISTROS = [
-    *ls_distro(name='debian92', os='debian', os_type='linux', os_ver='9.2'),  # CDRIVER-5873
-    *ls_distro(name='debian10', os='debian', os_type='linux', os_ver='10'),  # CDRIVER-5874
     *ls_distro(name='debian11', os='debian', os_type='linux', os_ver='11'),
+    *ls_distro(name='debian12', os='debian', os_type='linux', os_ver='12'),
 ]
 
 MACOS_DISTROS = [
@@ -63,7 +60,9 @@ MACOS_ARM64_DISTROS = [
 ]
 
 RHEL_DISTROS = [
-    *ls_distro(name='rhel76', os='rhel', os_type='linux', os_ver='7.6'),
+    *ls_distro(name='rhel7-latest', os='rhel', os_type='linux', os_ver='7'),
+    *ls_distro(name='rhel8-latest', os='rhel', os_type='linux', os_ver='8'),
+
     *ls_distro(name='rhel80', os='rhel', os_type='linux', os_ver='8.0'),
     *ls_distro(name='rhel84', os='rhel', os_type='linux', os_ver='8.4'),
     *ls_distro(name='rhel90', os='rhel', os_type='linux', os_ver='9.0'),
@@ -71,9 +70,7 @@ RHEL_DISTROS = [
     *ls_distro(name='rhel92', os='rhel', os_type='linux', os_ver='9.2'),
     *ls_distro(name='rhel93', os='rhel', os_type='linux', os_ver='9.3'),
     *ls_distro(name='rhel94', os='rhel', os_type='linux', os_ver='9.4'),
-    *ls_distro(name='rhel95', os='rhel', os_type='linux', os_ver='9.5'),
-    *ls_distro(name='rhel8.9', os='rhel', os_type='linux', os_ver='8.7'),
-    *ls_distro(name='rhel92', os='rhel', os_type='linux', os_ver='9.0'),
+    *ls_distro(name='rhel95', os='rhel', os_type='linux', os_ver='9.5'), # rhel9-latest
 ]
 
 RHEL_POWER_DISTROS = [
@@ -87,6 +84,7 @@ RHEL_ZSERIES_DISTROS = [
 UBUNTU_DISTROS = [
     *ls_distro(name='ubuntu2004', os='ubuntu', os_type='linux', os_ver='20.04'),
     *ls_distro(name='ubuntu2204', os='ubuntu', os_type='linux', os_ver='22.04'),
+    *ls_distro(name='ubuntu2404', os='ubuntu', os_type='linux', os_ver='24.04'),
 ]
 
 UBUNTU_ARM64_DISTROS = [
@@ -94,9 +92,6 @@ UBUNTU_ARM64_DISTROS = [
 ]
 
 WINDOWS_DISTROS = [
-    *ls_distro(name='windows-64-vs2017', os='windows', os_type='windows', vs_ver='2017'),
-    *ls_distro(name='windows-64-vs2019', os='windows', os_type='windows', vs_ver='2019'),
-
     *ls_distro(name='windows-vsCurrent', os='windows', os_type='windows', vs_ver='vsCurrent'),  # Windows Server 2019
 ]
 
@@ -109,6 +104,7 @@ GRAVITON_DISTROS = [
 # Ensure no-arch distros are ordered before arch-specific distros.
 ALL_DISTROS = [
     *DEBIAN_DISTROS,
+    *GRAVITON_DISTROS,
     *MACOS_DISTROS,
     *MACOS_ARM64_DISTROS,
     *RHEL_DISTROS,
@@ -117,7 +113,6 @@ ALL_DISTROS = [
     *UBUNTU_DISTROS,
     *UBUNTU_ARM64_DISTROS,
     *WINDOWS_DISTROS,
-    *GRAVITON_DISTROS
 ]
 
 
@@ -165,20 +160,7 @@ def make_distro_str(distro_name, compiler, arch) -> str:
             distro_str = 'windows-' + \
                 distro_name[len('windows-vsCurrent-'):] + f'-{compiler_str}'
         else:
-            distro_str = 'windows-2019' + f'-{compiler_str}'
-    elif distro_name.startswith('windows-64-vs'):
-        # Abbreviate 'windows-64-vs<type>' as 'vs<type>' and append '-<arch>' if
-        # given in compiler string as 'vs<type><arch>', e.g.:
-        #     ('windows-64-vs2017', 'vs2017x64', None) -> vs2017-x64
-        #     ('windows-64-vs2017', 'mingw',     None) -> vs2017-mingw
-        distro_str = distro_name[len('windows-64-'):] + {
-            'vs2017x64': '-x64',
-            'vs2017x86': '-x86',
-            'vs2019x64': '-x64',
-            'vs2019x86': '-x86',
-            'vs2022x64': '-x64',
-            'vs2022x86': '-x86',
-        }.get(compiler, f'-{compiler}')
+            distro_str = 'windows-2019-' + compiler_str
     else:
         distro_str = distro_name
         if compiler:
@@ -192,6 +174,8 @@ def make_distro_str(distro_name, compiler, arch) -> str:
 
 def to_cc(compiler):
     return {
+        'vs2015x64': 'Visual Studio 14 2015',
+        'vs2015x86': 'Visual Studio 14 2015',
         'vs2017x64': 'Visual Studio 15 2017',
         'vs2017x86': 'Visual Studio 15 2017',
         'vs2019x64': 'Visual Studio 16 2019',
@@ -203,6 +187,8 @@ def to_cc(compiler):
 
 def to_platform(compiler):
     return {
+        'vs2015x64': 'x64',
+        'vs2015x86': 'Win32',
         'vs2017x64': 'x64',
         'vs2017x86': 'Win32',
         'vs2019x64': 'x64',
@@ -213,6 +199,9 @@ def to_platform(compiler):
 
 
 def compiler_to_vars(compiler):
+    if compiler is None:
+        return {}
+
     match compiler, compiler.split('-'):
         case _, ['gcc', *rest]:
             return {
@@ -232,6 +221,12 @@ def compiler_to_vars(compiler):
                 'CMAKE_GENERATOR_PLATFORM': to_platform(vs),
             }
 
+        case _, ['mingw', *rest]:
+            return {
+                'CC': '-'.join(['gcc'] + rest),
+                'CXX': '-'.join(['g++'] + rest),
+            }
+
         case compiler, _:
             return {
                 'CC': compiler,
