@@ -193,18 +193,9 @@ all_tasks = [
     CompileTask("compile-tracing", TRACING="ON", CFLAGS="-Werror -Wno-cast-align"),
     CompileTask("release-compile", config="release"),
     CompileTask("debug-compile-nosasl-openssl", tags=["debug-compile", "nosasl", "openssl"], SSL="OPENSSL"),
-    CompileTask(
-        "debug-compile-nosasl-openssl-static", tags=["debug-compile", "nosasl", "openssl-static"], SSL="OPENSSL_STATIC"
-    ),
     CompileTask("debug-compile-nosasl-darwinssl", tags=["debug-compile", "nosasl", "darwinssl"], SSL="DARWIN"),
     CompileTask("debug-compile-nosasl-winssl", tags=["debug-compile", "nosasl", "winssl"], SSL="WINDOWS"),
     CompileTask("debug-compile-sasl-openssl", tags=["debug-compile", "sasl", "openssl"], SASL="AUTO", SSL="OPENSSL"),
-    CompileTask(
-        "debug-compile-sasl-openssl-static",
-        tags=["debug-compile", "sasl", "openssl-static"],
-        SASL="AUTO",
-        SSL="OPENSSL_STATIC",
-    ),
     CompileTask("debug-compile-sasl-darwinssl", tags=["debug-compile", "sasl", "darwinssl"], SASL="AUTO", SSL="DARWIN"),
     CompileTask("debug-compile-rdtscp", ENABLE_RDTSCP="ON"),
     CompileTask("debug-compile-sspi-winssl", tags=["debug-compile", "sspi", "winssl"], SASL="SSPI", SSL="WINDOWS"),
@@ -280,36 +271,6 @@ all_tasks = [
         ],
     ),
     CompileTask("debug-compile-with-warnings", CFLAGS="-Werror -Wno-cast-align"),
-    CompileTask(
-        "debug-compile-nosasl-openssl-1.0.1",
-        prefix_commands=[func("install ssl", SSL="openssl-1.0.1u")],
-        CFLAGS="-Wno-redundant-decls",
-        SSL="OPENSSL",
-        SASL="OFF",
-    ),
-    NamedTask(
-        "build-and-test-with-toolchain",
-        commands=[
-            OD(
-                [
-                    ("command", "s3.get"),
-                    (
-                        "params",
-                        OD(
-                            [
-                                ("aws_key", "${aws_key}"),
-                                ("aws_secret", "${aws_secret}"),
-                                ("remote_file", "mongo-c-toolchain/${distro_id}/2023/06/07/mongo-c-toolchain.tar.gz"),
-                                ("bucket", "mongo-c-toolchain"),
-                                ("local_file", "mongo-c-toolchain.tar.gz"),
-                            ]
-                        ),
-                    ),
-                ]
-            ),
-            shell_mongoc(".evergreen/scripts/build-and-test-with-toolchain.sh"),
-        ],
-    ),
     NamedTask(
         "install-libmongoc-after-libbson",
         commands=[shell_mongoc(".evergreen/scripts/install-libmongoc-after-libbson.sh"),],
@@ -601,12 +562,6 @@ class PostCompileTask(NamedTask):
 all_tasks = chain(
     all_tasks,
     [
-        PostCompileTask(
-            "test-mongohouse",
-            tags=[],
-            get_build="debug-compile-sasl-openssl",
-            commands=[func("fetch-det"), func("build mongohouse"), func("run mongohouse"), func("test mongohouse")],
-        ),
         NamedTask(
             "authentication-tests-asan-memcheck",
             tags=["authentication-tests", "asan"],
@@ -669,74 +624,6 @@ for server_version in [ "8.0", "7.0", "6.0", "5.0"]:
     )
 
 
-class SSLTask(Task):
-    def __init__(
-        self,
-        version: str,
-        patch: str,
-        cflags: str = "",
-        fips: bool = False,
-        enable_ssl: str | Literal[False] = False,
-        test_params: Mapping[str, Scalar] | None = None,
-    ):
-        full_version = version + patch + ("-fips" if fips else "")
-        self.enable_ssl = enable_ssl
-        script = "env"
-        if cflags:
-            script += f" CFLAGS={cflags}"
-
-        script += " SASL=OFF"
-
-        if enable_ssl is not False:
-            script += " SSL=" + enable_ssl
-        else:
-            script += " SSL=OPENSSL"
-
-        script += " .evergreen/scripts/compile.sh"
-
-        super(SSLTask, self).__init__(
-            commands=[
-                func("install ssl", SSL=full_version),
-                func("find-cmake-latest"),
-                shell_mongoc(script, add_expansions_to_env=True),
-                func("run auth tests", **(test_params or {})),
-                func("upload-build"),
-            ]
-        )
-
-        self.version = version
-        self.fips = fips
-
-    @property
-    def name(self):
-        s = "build-and-run-authentication-tests-" + self.version
-        if self.fips:
-            return s + "-fips"
-        if self.enable_ssl is not False:
-            return s + "-" + str(self.enable_ssl).lower()
-
-        return s
-
-
-all_tasks = chain(
-    all_tasks,
-    [
-        SSLTask(
-            "openssl-1.0.1",
-            "u",
-            cflags="-Wno-redundant-decls",
-        ),
-        SSLTask("openssl-1.0.1", "u", cflags="-Wno-redundant-decls", fips=True),
-        SSLTask(
-            "openssl-1.0.2",
-            "l",
-            cflags="-Wno-redundant-decls",
-        ),
-        SSLTask("openssl-1.1.0", "l")
-    ],
-)
-
-
 class IPTask(MatrixTask):
     axes = OD(
         [
@@ -799,7 +686,9 @@ aws_compile_task = NamedTask(
         func('find-cmake-latest'),
         shell_mongoc(
             """
-            export distro_id='${distro_id}' # Required by find_cmake_latest.
+            set -o errexit
+            set -o pipefail
+
             . .evergreen/scripts/find-cmake-latest.sh
             cmake_binary="$(find_cmake_latest)"
 
@@ -808,10 +697,11 @@ aws_compile_task = NamedTask(
             find_ccache_and_export_vars "$(pwd)" || true
 
             # Compile test-awsauth. Disable unnecessary dependencies since test-awsauth is copied to a remote Ubuntu 20.04 ECS cluster for testing, which may not have all dependent libraries.
-            export CC='${CC}'
-            "$cmake_binary" -DENABLE_TRACING=ON -DENABLE_SASL=OFF -DENABLE_SNAPPY=OFF -DENABLE_ZSTD=OFF -DENABLE_CLIENT_SIDE_ENCRYPTION=OFF .
-            "$cmake_binary" --build . --target test-awsauth
-            """
+            "$cmake_binary" -DENABLE_TRACING=ON -DENABLE_SASL=OFF -DENABLE_SNAPPY=OFF -DENABLE_ZSTD=OFF -DENABLE_CLIENT_SIDE_ENCRYPTION=OFF -S . -B cmake-build
+            "$cmake_binary" --build cmake-build --target test-awsauth
+            """,
+            include_expansions_in_env=['distro_id', 'CC'],
+            redirect_standard_error_to_output=True,
         ),
         func("upload-build"),
     ],
@@ -878,7 +768,7 @@ class OCSPTask(MatrixTask):
             ),
             ("delegate", ["delegate", "nodelegate"]),
             ("cert", ["rsa", "ecdsa"]),
-            ("ssl", ["openssl", "openssl-1.0.1", "darwinssl", "winssl"]),
+            ("ssl", ["openssl", "darwinssl", "winssl"]),
             ("version", ["latest", "8.0", "7.0", "6.0", "5.0", "4.4"]),
         ]
     )
@@ -937,41 +827,24 @@ class OCSPTask(MatrixTask):
 
         yield (orchestration)
 
-        if self.build_task_name == "debug-compile-nosasl-openssl-1.0.1":
-            # LD_LIBRARY_PATH is needed so the in-tree OpenSSL 1.0.1 is found at runtime
-            if self.test == "cache":
-                yield (
-                    shell_mongoc(
-                        f"""
-                        LD_LIBRARY_PATH=$(pwd)/install-dir/lib CERT_TYPE={self.settings.cert} .evergreen/scripts/run-ocsp-cache-test.sh
-                        """
-                    )
-                )
-            else:
-                yield (
-                    shell_mongoc(
-                        f"""
-                        LD_LIBRARY_PATH=$(pwd)/install-dir/lib TEST_COLUMN={self.test.upper()} CERT_TYPE={self.settings.cert} .evergreen/scripts/run-ocsp-test.sh
-                        """
-                    )
+        if self.test == "cache":
+            yield (
+                shell_mongoc(
+                    f"""
+                    CERT_TYPE={self.settings.cert} .evergreen/scripts/run-ocsp-cache-test.sh
+                    """,
+                    redirect_standard_error_to_output=True,
                 )
+            )
         else:
-            if self.test == "cache":
-                yield (
-                    shell_mongoc(
-                        f"""
-                        CERT_TYPE={self.settings.cert} .evergreen/scripts/run-ocsp-cache-test.sh
-                        """
-                    )
-                )
-            else:
-                yield (
-                    shell_mongoc(
-                        f"""
-                        TEST_COLUMN={self.test.upper()} CERT_TYPE={self.settings.cert} .evergreen/scripts/run-ocsp-test.sh
-                        """
-                    )
+            yield (
+                shell_mongoc(
+                    f"""
+                    TEST_COLUMN={self.test.upper()} CERT_TYPE={self.settings.cert} .evergreen/scripts/run-ocsp-test.sh
+                    """,
+                    redirect_standard_error_to_output=True,
                 )
+            )
 
     def to_dict(self):
         task = super(MatrixTask, self).to_dict()
@@ -988,16 +861,26 @@ class OCSPTask(MatrixTask):
             # Secure Transport quietly ignores a must-staple certificate with no stapled response.
             prohibit(self.test == "malicious_server_test_2")
 
-        # ECDSA certs can't be loaded (in the PEM format they're stored) on Windows/macOS. Skip them.
+            # Why does this fail with Secure Transport (CSSMERR_TP_CERT_SUSPENDED)...?
+            prohibit(self.test == "test_3")
+
+            # CDRIVER-3759: Secure Transport does not implement soft failure?
+            prohibit(self.test == "soft_fail_test")
+
+            # Only Server 6.0+ are available on MacOS ARM64.
+            if self.settings.version != "latest":
+                prohibit(Version(self.settings.version) < Version("6.0"))
+
         if self.settings.ssl == "darwinssl" or self.settings.ssl == "winssl":
+            # ECDSA certs can't be loaded (in the PEM format they're stored) on Windows/macOS. Skip them.
             prohibit(self.settings.cert == "ecdsa")
 
-        # OCSP stapling is not supported on macOS or Windows.
-        if self.settings.ssl == "darwinssl" or self.settings.ssl == "winssl":
+            # OCSP stapling is not supported on macOS or Windows.
             prohibit(self.test in ["test_1", "test_2", "cache"])
 
         if self.test == "soft_fail_test" or self.test == "malicious_server_test_2" or self.test == "cache":
             prohibit(self.settings.delegate == "delegate")
+
         return True
 
 
