@@ -27,8 +27,8 @@
 #include <stdlib.h>
 #include <limits.h> /* CHAR_BIT */
 
-bool rfc_3986_tab[256] = {0};
-bool kms_initialized = false;
+static bool rfc_3986_tab[256] = {0};
+static bool kms_initialized = false;
 
 static void
 tables_init (void)
@@ -126,12 +126,6 @@ kms_request_str_detach (kms_request_str_t *str)
    return r;
 }
 
-const char *
-kms_request_str_get (kms_request_str_t *str)
-{
-   return str->str;
-}
-
 bool
 kms_request_str_reserve (kms_request_str_t *str, size_t size)
 {
@@ -366,7 +360,7 @@ kms_request_str_append_hashed (_kms_crypto_t *crypto,
                                kms_request_str_t *str,
                                kms_request_str_t *appended)
 {
-   uint8_t hash[32];
+   uint8_t hash[32] = {0};
    char *hex_chars;
 
    if (!crypto->sha256 (crypto->ctx, appended->str, appended->len, hash)) {
