@@ -1,6 +1,6 @@
-#include <stdint.h>
+#include "./validate.hpp"
 
-#include "validate.hpp"
+#include <stdint.h>
 
 extern "C" int
 LLVMFuzzerTestOneInput (const uint8_t *data, size_t size)
