@@ -15,17 +15,19 @@
  */
 
 
+#include <common-bits-private.h>
+#include <common-string-private.h>
+
+#include <bson/bson-utf8.h>
+#include <bson/compat.h>
+#include <bson/config.h>
+#include <bson/memory.h>
+
+#include <mlib/cmp.h>
+
 #include <limits.h>
 #include <stdarg.h>
 
-#include <bson/bson-compat.h>
-#include <bson/bson-config.h>
-#include <mlib/cmp.h>
-#include <common-string-private.h>
-#include <common-bits-private.h>
-#include <bson/bson-memory.h>
-#include <bson/bson-utf8.h>
-
 #ifdef BSON_HAVE_STRINGS_H
 #include <strings.h>
 #else
