@@ -15,15 +15,18 @@
  */
 
 
-#include <string.h>
+#include <bson/bson-utf8.h>
 
-#include <bson/bson-memory.h>
-#include <mlib/cmp.h>
 #include <common-json-private.h>
 #include <common-macros-private.h>
 #include <common-string-private.h>
 #include <common-utf8-private.h>
-#include <bson/bson-utf8.h>
+
+#include <bson/memory.h>
+
+#include <mlib/cmp.h>
+
+#include <string.h>
 
 
 /*
