@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,9 +15,10 @@
  */
 
 
-#include <bson/bson-private.h>
 #include <bson/bson-writer.h>
 
+#include <bson/bson-private.h>
+
 
 struct _bson_writer_t {
    bool ready;
@@ -198,8 +199,7 @@ bson_writer_begin (bson_writer_t *writer, /* IN */
    }
 
    if (grown) {
-      *writer->buf = writer->realloc_func (
-         *writer->buf, *writer->buflen, writer->realloc_func_ctx);
+      *writer->buf = writer->realloc_func (*writer->buf, *writer->buflen, writer->realloc_func_ctx);
    }
 
    memset ((*writer->buf) + writer->offset + 1, 0, 5);
