@@ -4,7 +4,7 @@
  */
 
 #include <jsonsl/jsonsl.h>
-#include <bson/bson-memory.h>
+#include <bson/memory.h>
 
 #include <limits.h>
 #include <ctype.h>
@@ -144,34 +144,44 @@ jsonsl_feed(jsonsl_t jsn, const jsonsl_char_t *bytes, size_t nbytes)
 {
 
 #define INVOKE_ERROR(eb) \
-    if (jsn->error_callback(jsn, JSONSL_ERROR_##eb, state, (char*)c)) { \
-        goto GT_AGAIN; \
-    } \
-    return;
+    if (1) { \
+        if (jsn->error_callback(jsn, JSONSL_ERROR_##eb, state, (char*)c)) { \
+            goto GT_AGAIN; \
+        } \
+        return; \
+    } else ((void)0)
 
 #define STACK_PUSH \
-    if (jsn->level >= (levels_max-1)) { \
-        jsn->error_callback(jsn, JSONSL_ERROR_LEVELS_EXCEEDED, state, (char*)c); \
-        return; \
-    } \
-    state = jsn->stack + (++jsn->level); \
-    state->ignore_callback = jsn->stack[jsn->level-1].ignore_callback; \
-    state->pos_begin = jsn->pos;
+    if (1) { \
+        if (jsn->level >= (levels_max-1)) { \
+            jsn->error_callback(jsn, JSONSL_ERROR_LEVELS_EXCEEDED, state, (char*)c); \
+            return; \
+        } \
+        state = jsn->stack + (++jsn->level); \
+        state->ignore_callback = jsn->stack[jsn->level-1].ignore_callback; \
+        state->pos_begin = jsn->pos; \
+    } else ((void)0)
 
 #define CALLBACK_AND_POP_NOPOS(T) \
+    if (1) { \
         state->pos_cur = jsn->pos; \
         DO_CALLBACK(T, POP); \
         state->nescapes = 0; \
-        state = jsn->stack + (--jsn->level);
+        state = jsn->stack + (--jsn->level); \
+    } else ((void)0)
 
 #define CALLBACK_AND_POP(T) \
+    if (1) { \
         CALLBACK_AND_POP_NOPOS(T); \
-        state->pos_cur = jsn->pos;
+        state->pos_cur = jsn->pos; \
+    } else ((void)0)
 
 #define SPECIAL_POP \
-    CALLBACK_AND_POP(SPECIAL); \
-    jsn->expecting = 0; \
-    jsn->tok_last = 0; \
+    if (1) { \
+        CALLBACK_AND_POP(SPECIAL); \
+        jsn->expecting = 0; \
+        jsn->tok_last = 0; \
+    } else ((void)0)
 
 #define CUR_CHAR (*(jsonsl_uchar_t*)c)
 
@@ -186,7 +196,7 @@ jsonsl_feed(jsonsl_t jsn, const jsonsl_char_t *bytes, size_t nbytes)
             jsn->action_callback(jsn, JSONSL_ACTION_##action, state, (jsonsl_char_t*)c); \
         } \
         if (jsn->stopfl) { return; } \
-    }
+    } else ((void)0)
 
     /**
      * Verifies that we are able to insert the (non-string) item into a hash.
@@ -194,19 +204,19 @@ jsonsl_feed(jsonsl_t jsn, const jsonsl_char_t *bytes, size_t nbytes)
 #define ENSURE_HVAL \
     if (state->nelem % 2 == 0 && state->type == JSONSL_T_OBJECT) { \
         INVOKE_ERROR(HKEY_EXPECTED); \
-    }
+    } else ((void)0)
 
 #define VERIFY_SPECIAL(lit, lit_len) \
-        if ((jsn->pos - state->pos_begin) > lit_len \
-                || CUR_CHAR != (lit)[jsn->pos - state->pos_begin]) { \
-            INVOKE_ERROR(SPECIAL_EXPECTED); \
-        }
+    if ((jsn->pos - state->pos_begin) > lit_len \
+            || CUR_CHAR != (lit)[jsn->pos - state->pos_begin]) { \
+        INVOKE_ERROR(SPECIAL_EXPECTED); \
+    } else ((void)0)
 
 #define VERIFY_SPECIAL_CI(lit, lit_len) \
-        if ((jsn->pos - state->pos_begin) > lit_len \
-                || tolower(CUR_CHAR) != (lit)[jsn->pos - state->pos_begin]) { \
-            INVOKE_ERROR(SPECIAL_EXPECTED); \
-        }
+    if ((jsn->pos - state->pos_begin) > lit_len \
+            || tolower(CUR_CHAR) != (lit)[jsn->pos - state->pos_begin]) { \
+        INVOKE_ERROR(SPECIAL_EXPECTED); \
+    } else ((void)0)
 
 #define STATE_SPECIAL_LENGTH \
     (state)->nescapes
@@ -663,7 +673,7 @@ const char* jsonsl_strerror(jsonsl_error_t err)
 #define X(t) \
     if (err == JSONSL_ERROR_##t) \
         return #t;
-    JSONSL_XERR;
+    JSONSL_XERR
 #undef X
     return "<UNKNOWN_ERROR>";
 }
@@ -787,7 +797,7 @@ jsonsl_jpr_new(const char *path, jsonsl_error_t *errp)
     size_t origlen;
     jsonsl_error_t errstacked;
 
-#define JPR_BAIL(err) *errp = err; goto GT_ERROR;
+#define JPR_BAIL(err) if (1) { *errp = err; goto GT_ERROR; } else ((void)0)
 
     if (errp == NULL) {
         errp = &errstacked;
@@ -1042,9 +1052,9 @@ void jsonsl_jpr_match_state_init(jsonsl_t jsn,
     if (njprs == 0) {
         return;
     }
-    jsn->jprs = (jsonsl_jpr_t *)malloc(sizeof(jsonsl_jpr_t) * njprs);
+    jsn->jprs = (jsonsl_jpr_t *) bson_malloc (sizeof (jsonsl_jpr_t) * njprs);
     jsn->jpr_count = njprs;
-    jsn->jpr_root = (size_t*)calloc(1, sizeof(size_t) * njprs * jsn->levels_max);
+    jsn->jpr_root = (size_t *) bson_malloc0 (sizeof (size_t) * njprs * jsn->levels_max);
     memcpy(jsn->jprs, jprs, sizeof(jsonsl_jpr_t) * njprs);
     /* Set the initial jump table values */
 
@@ -1060,8 +1070,8 @@ void jsonsl_jpr_match_state_cleanup(jsonsl_t jsn)
         return;
     }
 
-    free(jsn->jpr_root);
-    free(jsn->jprs);
+    bson_free(jsn->jpr_root);
+    bson_free(jsn->jprs);
     jsn->jprs = NULL;
     jsn->jpr_root = NULL;
     jsn->jpr_count = 0;
@@ -1157,7 +1167,7 @@ const char *jsonsl_strmatchtype(jsonsl_jpr_match_t match)
 static char *
 jsonsl__writeutf8(uint32_t pt, char *out)
 {
-    #define ADD_OUTPUT(c) *out = (char)(c); out++;
+    #define ADD_OUTPUT(c) if (1) { *out = (char)(c); out++; } else ((void)0)
 
     if (pt < 0x80) {
         ADD_OUTPUT(pt);
@@ -1204,9 +1214,11 @@ jsonsl__get_uescape_16(const char *s)
     int cur;
 
     #define GET_DIGIT(off) \
-        cur = jsonsl__digit2int(s[off]); \
-        if (cur == -1) { return -1; } \
-        ret |= (cur << (12 - (off * 4)));
+        if (1) { \
+            cur = jsonsl__digit2int(s[off]); \
+            if (cur == -1) { return -1; } \
+            ret |= (cur << (12 - (off * 4))); \
+        } else ((void)0)
 
     GET_DIGIT(0);
     GET_DIGIT(1);
@@ -1238,11 +1250,13 @@ size_t jsonsl_util_unescape_ex(const char *in,
     *oflags = 0;
 
     #define UNESCAPE_BAIL(e,offset) \
-        *err = JSONSL_ERROR_##e; \
-        if (errat) { \
-            *errat = (const char*)(c+ (ptrdiff_t)(offset)); \
-        } \
-        return 0;
+        if (1) { \
+            *err = JSONSL_ERROR_##e; \
+            if (errat) { \
+                *errat = (const char*)(c+ (ptrdiff_t)(offset)); \
+            } \
+            return 0; \
+        } else ((void)0)
 
     for (; len; len--, c++, out++) {
         int uescval;
@@ -1255,7 +1269,7 @@ size_t jsonsl_util_unescape_ex(const char *in,
             UNESCAPE_BAIL(ESCAPE_INVALID, 0);
         }
         if (!is_allowed_escape(c[1])) {
-            UNESCAPE_BAIL(ESCAPE_INVALID, 1)
+            UNESCAPE_BAIL(ESCAPE_INVALID, 1);
         }
         if ((toEscape && toEscape[(unsigned char)c[1] & 0x7f] == 0 &&
                 c[1] != '\\' && c[1] != '"')) {
