@@ -17,7 +17,7 @@
 
 #include <bson/bson.h>
 
-#include "TestSuite.h"
+#include <TestSuite.h>
 
 
 static void
