@@ -17,9 +17,10 @@
 
 #include <bson/bson.h>
 
-#include "TestSuite.h"
 #include <mlib/intencode.h>
 
+#include <TestSuite.h>
+
 #define FUZZ_N_PASSES 100000
 
 static bson_t *
