@@ -1,9 +1,10 @@
+#include "./client-side-encryption-helpers.h"
+
 #include <mongoc/mongoc.h>
+
 #include <stdio.h>
 #include <stdlib.h>
 
-#include "client-side-encryption-helpers.h"
-
 /* Helper method to create and return a JSON schema to use for encryption.
 The caller will use the returned schema for server-side encryption validation.
 */
