@@ -1,5 +1,5 @@
 /*
- * Copyright 2015 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,16 +14,17 @@
  * limitations under the License.
  */
 
-#include "mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
 
 #ifndef MONGOC_CLIENT_POOL_PRIVATE_H
 #define MONGOC_CLIENT_POOL_PRIVATE_H
 
-#include <bson/bson.h>
+#include <mongoc/mongoc-topology-private.h>
 
-#include "mongoc-client-pool.h"
-#include "mongoc-topology-description.h"
-#include "mongoc-topology-private.h"
+#include <mongoc/mongoc-client-pool.h>
+#include <mongoc/mongoc-topology-description.h>
+
+#include <bson/bson.h>
 
 BSON_BEGIN_DECLS
 
