@@ -1,5 +1,5 @@
 /*
- * Copyright 2020-present MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,15 +14,17 @@
  * limitations under the License.
  */
 
-#include "mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
 
 #ifndef MONGOC_CLUSTER_AWS_PRIVATE_H
 #define MONGOC_CLUSTER_AWS_PRIVATE_H
 
-#include "bson/bson.h"
-#include "mcd-time.h"
-#include "mongoc/mongoc-cluster-private.h"
-#include "common-thread-private.h" // bson_mutex_t
+#include <common-thread-private.h> // bson_mutex_t
+#include <mongoc/mongoc-cluster-private.h>
+
+#include <mongoc/mcd-time.h>
+
+#include <bson/bson.h>
 
 bool
 _mongoc_cluster_auth_node_aws (mongoc_cluster_t *cluster,
