@@ -14,9 +14,10 @@
  * limitations under the License.
  */
 
-#include "mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
+
+#include <mongoc/mongoc-config.h>
 
-#include "mongoc-config.h"
 #include <bson/bson.h>
 
 #ifdef MONGOC_ENABLE_CRYPTO_LIBCRYPTO
@@ -24,7 +25,7 @@
 #ifndef MONGOC_CRYPTO_OPENSSL_PRIVATE_H
 #define MONGOC_CRYPTO_OPENSSL_PRIVATE_H
 
-#include "mongoc-crypto-private.h"
+#include <mongoc/mongoc-crypto-private.h>
 
 BSON_BEGIN_DECLS
 
