@@ -1,5 +1,5 @@
 /*
- * Copyright 2014 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,16 +14,17 @@
  * limitations under the License.
  */
 
-#include "mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
 
 #ifndef MONGOC_ERRNO_PRIVATE_H
 #define MONGOC_ERRNO_PRIVATE_H
 
 #include <bson/bson.h>
+
 #include <errno.h>
 #ifdef _WIN32
-#include <winsock2.h>
 #include <winerror.h>
+#include <winsock2.h>
 #endif
 
 
@@ -33,11 +34,6 @@ BSON_BEGIN_DECLS
 #if defined(_WIN32)
 #define MONGOC_ERRNO_IS_AGAIN(errno) ((errno == EAGAIN) || (errno == WSAEWOULDBLOCK) || (errno == WSAEINPROGRESS))
 #define MONGOC_ERRNO_IS_TIMEDOUT(errno) (errno == WSAETIMEDOUT)
-#elif defined(__sun)
-/* for some reason, accept() returns -1 and errno of 0 */
-#define MONGOC_ERRNO_IS_AGAIN(errno) \
-   ((errno == EINTR) || (errno == EAGAIN) || (errno == EWOULDBLOCK) || (errno == EINPROGRESS) || (errno == 0))
-#define MONGOC_ERRNO_IS_TIMEDOUT(errno) (errno == ETIMEDOUT)
 #else
 #define MONGOC_ERRNO_IS_AGAIN(errno) \
    ((errno == EINTR) || (errno == EAGAIN) || (errno == EWOULDBLOCK) || (errno == EINPROGRESS))
