@@ -1,5 +1,5 @@
 /*
- * Copyright 2015 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,11 +15,13 @@
  */
 
 
-#include "mongoc-write-concern.h"
-#include "mongoc-write-concern-private.h"
-#include "mongoc-find-and-modify.h"
-#include "mongoc-find-and-modify-private.h"
-#include "mongoc-util-private.h"
+#include <mongoc/mongoc-find-and-modify.h>
+
+#include <mongoc/mongoc-find-and-modify-private.h>
+#include <mongoc/mongoc-util-private.h>
+#include <mongoc/mongoc-write-concern-private.h>
+
+#include <mongoc/mongoc-write-concern.h>
 
 
 /**
