@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 MongoDB Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,16 +14,16 @@
  * limitations under the License.
  */
 
-#include "mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
 
 #ifndef MONGOC_GRIDFS_PRIVATE_H
 #define MONGOC_GRIDFS_PRIVATE_H
 
-#include <bson/bson.h>
+#include <mongoc/mongoc-client.h>
+#include <mongoc/mongoc-read-prefs.h>
+#include <mongoc/mongoc-write-concern.h>
 
-#include "mongoc-read-prefs.h"
-#include "mongoc-write-concern.h"
-#include "mongoc-client.h"
+#include <bson/bson.h>
 
 
 BSON_BEGIN_DECLS
