@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,19 +14,18 @@
  * limitations under the License.
  */
 
-#include "mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
 
 #ifndef MONGOC_HOST_LIST_PRIVATE_H
 #define MONGOC_HOST_LIST_PRIVATE_H
 
-#include "mongoc-host-list.h"
+#include <mongoc/mongoc-host-list.h>
+
+#include <mlib/str.h>
 
 
 BSON_BEGIN_DECLS
 
-mongoc_host_list_t *
-_mongoc_host_list_push (const char *host, uint16_t port, int family, mongoc_host_list_t *next);
-
 void
 _mongoc_host_list_upsert (mongoc_host_list_t **list, const mongoc_host_list_t *new_host);
 
@@ -41,7 +40,7 @@ _mongoc_host_list_from_string_with_err (mongoc_host_list_t *host_list, const cha
 
 bool
 _mongoc_host_list_from_hostport_with_err (mongoc_host_list_t *host_list,
-                                          const char *host,
+                                          mstr_view host,
                                           uint16_t port,
                                           bson_error_t *error);
 
