@@ -1,5 +1,5 @@
 /*
- * Copyright 2021 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-#include "mongoc-optional.h"
+#include <mongoc/mongoc-optional.h>
 
 void
 mongoc_optional_init (mongoc_optional_t *opt)
