@@ -1,5 +1,5 @@
 /*
- * Copyright 2014 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,19 +14,16 @@
  * limitations under the License.
  */
 
-
-#if !defined(MONGOC_INSIDE) && !defined(MONGOC_COMPILATION)
-#error "Only <mongoc/mongoc.h> can be included directly."
-#endif
+#include <mongoc/mongoc-prelude.h>
 
 
 #ifndef MONGOC_RAND_H
 #define MONGOC_RAND_H
 
 
-#include <bson/bson.h>
+#include <mongoc/mongoc-macros.h>
 
-#include "mongoc/mongoc-macros.h"
+#include <bson/bson.h>
 
 BSON_BEGIN_DECLS
 
