@@ -1,5 +1,5 @@
 /*
- * Copyright 2021 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,8 +15,9 @@
  */
 
 
-#include "mongoc-config.h"
-#include "mongoc-server-api-private.h"
+#include <mongoc/mongoc-server-api-private.h>
+
+#include <mongoc/mongoc-config.h>
 
 const char *
 mongoc_server_api_version_to_string (mongoc_server_api_version_t version)
