@@ -14,21 +14,23 @@
  * limitations under the License.
  */
 
-#include <mongoc/mongoc-config.h>
+#include <common-atomic-private.h>
+#include <common-bson-dsl-private.h>
+#include <common-oid-private.h>
+#include <mongoc/mongoc-compression-private.h>
 #include <mongoc/mongoc-error-private.h>
-#include <mongoc/mongoc-host-list.h>
 #include <mongoc/mongoc-host-list-private.h>
-#include <mongoc/mongoc-read-prefs.h>
 #include <mongoc/mongoc-read-prefs-private.h>
 #include <mongoc/mongoc-server-description-private.h>
 #include <mongoc/mongoc-trace-private.h>
-#include <mongoc/mongoc-uri.h>
 #include <mongoc/mongoc-util-private.h>
-#include <mongoc/mongoc-compression-private.h>
 
-#include <common-bson-dsl-private.h>
-#include <common-atomic-private.h>
-#include <common-oid-private.h>
+#include <mongoc/mongoc-config.h>
+#include <mongoc/mongoc-host-list.h>
+#include <mongoc/mongoc-read-prefs.h>
+#include <mongoc/mongoc-uri.h>
+
+#include <mlib/config.h>
 
 #include <stdio.h>
 
@@ -527,7 +529,7 @@ mongoc_server_description_handle_hello (mongoc_server_description_t *sd,
    }
 
    bson_destroy (&sd->last_hello_response);
-   bsonBuild (sd->last_hello_response, insert (*hello_response, not(key ("speculativeAuthenticate"))));
+   bsonBuild (sd->last_hello_response, insert (*hello_response, not (key ("speculativeAuthenticate"))));
    sd->has_hello_response = true;
 
    /* Only reinitialize the topology version if we have a hello response.
@@ -556,28 +558,34 @@ mongoc_server_description_handle_hello (mongoc_server_description_t *sd,
          }
       } else if (strcmp ("isWritablePrimary", bson_iter_key (&iter)) == 0 ||
                  strcmp (HANDSHAKE_RESPONSE_LEGACY_HELLO, bson_iter_key (&iter)) == 0) {
-         if (!BSON_ITER_HOLDS_BOOL (&iter))
+         if (!BSON_ITER_HOLDS_BOOL (&iter)) {
             GOTO (typefailure);
+         }
          is_primary = bson_iter_bool (&iter);
       } else if (strcmp ("helloOk", bson_iter_key (&iter)) == 0) {
-         if (!BSON_ITER_HOLDS_BOOL (&iter))
+         if (!BSON_ITER_HOLDS_BOOL (&iter)) {
             GOTO (typefailure);
+         }
          sd->hello_ok = bson_iter_bool (&iter);
       } else if (strcmp ("me", bson_iter_key (&iter)) == 0) {
-         if (!BSON_ITER_HOLDS_UTF8 (&iter))
+         if (!BSON_ITER_HOLDS_UTF8 (&iter)) {
             GOTO (typefailure);
+         }
          sd->me = bson_iter_utf8 (&iter, NULL);
       } else if (strcmp ("maxMessageSizeBytes", bson_iter_key (&iter)) == 0) {
-         if (!BSON_ITER_HOLDS_INT32 (&iter))
+         if (!BSON_ITER_HOLDS_INT32 (&iter)) {
             GOTO (typefailure);
+         }
          sd->max_msg_size = bson_iter_int32 (&iter);
       } else if (strcmp ("maxBsonObjectSize", bson_iter_key (&iter)) == 0) {
-         if (!BSON_ITER_HOLDS_INT32 (&iter))
+         if (!BSON_ITER_HOLDS_INT32 (&iter)) {
             GOTO (typefailure);
+         }
          sd->max_bson_obj_size = bson_iter_int32 (&iter);
       } else if (strcmp ("maxWriteBatchSize", bson_iter_key (&iter)) == 0) {
-         if (!BSON_ITER_HOLDS_INT32 (&iter))
+         if (!BSON_ITER_HOLDS_INT32 (&iter)) {
             GOTO (typefailure);
+         }
          sd->max_write_batch_size = bson_iter_int32 (&iter);
       } else if (strcmp ("logicalSessionTimeoutMinutes", bson_iter_key (&iter)) == 0) {
          if (BSON_ITER_HOLDS_NUMBER (&iter)) {
@@ -589,68 +597,81 @@ mongoc_server_description_handle_hello (mongoc_server_description_t *sd,
             GOTO (typefailure);
          }
       } else if (strcmp ("minWireVersion", bson_iter_key (&iter)) == 0) {
-         if (!BSON_ITER_HOLDS_INT32 (&iter))
+         if (!BSON_ITER_HOLDS_INT32 (&iter)) {
             GOTO (typefailure);
+         }
          sd->min_wire_version = bson_iter_int32 (&iter);
       } else if (strcmp ("maxWireVersion", bson_iter_key (&iter)) == 0) {
-         if (!BSON_ITER_HOLDS_INT32 (&iter))
+         if (!BSON_ITER_HOLDS_INT32 (&iter)) {
             GOTO (typefailure);
+         }
          sd->max_wire_version = bson_iter_int32 (&iter);
       } else if (strcmp ("msg", bson_iter_key (&iter)) == 0) {
          const char *msg;
-         if (!BSON_ITER_HOLDS_UTF8 (&iter))
+         if (!BSON_ITER_HOLDS_UTF8 (&iter)) {
             GOTO (typefailure);
+         }
          msg = bson_iter_utf8 (&iter, NULL);
          if (msg && 0 == strcmp (msg, "isdbgrid")) {
             is_shard = true;
          }
       } else if (strcmp ("setName", bson_iter_key (&iter)) == 0) {
-         if (!BSON_ITER_HOLDS_UTF8 (&iter))
+         if (!BSON_ITER_HOLDS_UTF8 (&iter)) {
             GOTO (typefailure);
+         }
          sd->set_name = bson_iter_utf8 (&iter, NULL);
       } else if (strcmp ("setVersion", bson_iter_key (&iter)) == 0) {
          mongoc_server_description_set_set_version (sd, bson_iter_as_int64 (&iter));
       } else if (strcmp ("electionId", bson_iter_key (&iter)) == 0) {
-         if (!BSON_ITER_HOLDS_OID (&iter))
+         if (!BSON_ITER_HOLDS_OID (&iter)) {
             GOTO (typefailure);
+         }
          mongoc_server_description_set_election_id (sd, bson_iter_oid (&iter));
       } else if (strcmp ("secondary", bson_iter_key (&iter)) == 0) {
-         if (!BSON_ITER_HOLDS_BOOL (&iter))
+         if (!BSON_ITER_HOLDS_BOOL (&iter)) {
             GOTO (typefailure);
+         }
          is_secondary = bson_iter_bool (&iter);
       } else if (strcmp ("hosts", bson_iter_key (&iter)) == 0) {
-         if (!BSON_ITER_HOLDS_ARRAY (&iter))
+         if (!BSON_ITER_HOLDS_ARRAY (&iter)) {
             GOTO (typefailure);
+         }
          bson_iter_array (&iter, &len, &bytes);
          bson_destroy (&sd->hosts);
          BSON_ASSERT (bson_init_static (&sd->hosts, bytes, len));
       } else if (strcmp ("passives", bson_iter_key (&iter)) == 0) {
-         if (!BSON_ITER_HOLDS_ARRAY (&iter))
+         if (!BSON_ITER_HOLDS_ARRAY (&iter)) {
             GOTO (typefailure);
+         }
          bson_iter_array (&iter, &len, &bytes);
          bson_destroy (&sd->passives);
          BSON_ASSERT (bson_init_static (&sd->passives, bytes, len));
       } else if (strcmp ("arbiters", bson_iter_key (&iter)) == 0) {
-         if (!BSON_ITER_HOLDS_ARRAY (&iter))
+         if (!BSON_ITER_HOLDS_ARRAY (&iter)) {
             GOTO (typefailure);
+         }
          bson_iter_array (&iter, &len, &bytes);
          bson_destroy (&sd->arbiters);
          BSON_ASSERT (bson_init_static (&sd->arbiters, bytes, len));
       } else if (strcmp ("primary", bson_iter_key (&iter)) == 0) {
-         if (!BSON_ITER_HOLDS_UTF8 (&iter))
+         if (!BSON_ITER_HOLDS_UTF8 (&iter)) {
             GOTO (typefailure);
+         }
          sd->current_primary = bson_iter_utf8 (&iter, NULL);
       } else if (strcmp ("arbiterOnly", bson_iter_key (&iter)) == 0) {
-         if (!BSON_ITER_HOLDS_BOOL (&iter))
+         if (!BSON_ITER_HOLDS_BOOL (&iter)) {
             GOTO (typefailure);
+         }
          is_arbiter = bson_iter_bool (&iter);
       } else if (strcmp ("isreplicaset", bson_iter_key (&iter)) == 0) {
-         if (!BSON_ITER_HOLDS_BOOL (&iter))
+         if (!BSON_ITER_HOLDS_BOOL (&iter)) {
             GOTO (typefailure);
+         }
          is_replicaset = bson_iter_bool (&iter);
       } else if (strcmp ("tags", bson_iter_key (&iter)) == 0) {
-         if (!BSON_ITER_HOLDS_DOCUMENT (&iter))
+         if (!BSON_ITER_HOLDS_DOCUMENT (&iter)) {
             GOTO (typefailure);
+         }
          bson_iter_document (&iter, &len, &bytes);
          bson_destroy (&sd->tags);
          BSON_ASSERT (bson_init_static (&sd->tags, bytes, len));
@@ -664,8 +685,9 @@ mongoc_server_description_handle_hello (mongoc_server_description_t *sd,
 
          sd->last_write_date_ms = bson_iter_date_time (&child);
       } else if (strcmp ("compression", bson_iter_key (&iter)) == 0) {
-         if (!BSON_ITER_HOLDS_ARRAY (&iter))
+         if (!BSON_ITER_HOLDS_ARRAY (&iter)) {
             GOTO (typefailure);
+         }
          bson_iter_array (&iter, &len, &bytes);
          bson_destroy (&sd->compressors);
          BSON_ASSERT (bson_init_static (&sd->compressors, bytes, len));
@@ -681,12 +703,14 @@ mongoc_server_description_handle_hello (mongoc_server_description_t *sd,
          mongoc_server_description_set_topology_version (sd, &incoming_topology_version);
          bson_destroy (&incoming_topology_version);
       } else if (strcmp ("serviceId", bson_iter_key (&iter)) == 0) {
-         if (!BSON_ITER_HOLDS_OID (&iter))
+         if (!BSON_ITER_HOLDS_OID (&iter)) {
             GOTO (typefailure);
+         }
          bson_oid_copy_unsafe (bson_iter_oid (&iter), &sd->service_id);
       } else if (strcmp ("connectionId", bson_iter_key (&iter)) == 0) {
-         if (!BSON_ITER_HOLDS_NUMBER (&iter))
+         if (!BSON_ITER_HOLDS_NUMBER (&iter)) {
             GOTO (typefailure);
+         }
          sd->server_connection_id = bson_iter_as_int64 (&iter);
       }
    }
@@ -770,7 +794,7 @@ mongoc_server_description_new_copy (const mongoc_server_description_t *descripti
          const uint8_t *data = bson_get_data (&copy->last_hello_response) + offset;                                  \
          uint32_t len = description->FIELD.len;                                                                      \
          MONGOC_DEBUG_ASSERT (offset + len <= copy->last_hello_response.len);                                        \
-         bson_init_static (&copy->FIELD, data, len);                                                                 \
+         BSON_ASSERT (bson_init_static (&copy->FIELD, data, len));                                                   \
       } else {                                                                                                       \
          bson_init (&copy->FIELD);                                                                                   \
       }                                                                                                              \
