@@ -14,11 +14,11 @@
  * limitations under the License.
  */
 
-#include "mongoc-counters-private.h"
-#include "mongoc-gridfs-bucket-file-private.h"
-#include "mongoc-trace-private.h"
-#include "mongoc-stream-gridfs-upload-private.h"
-#include "mongoc-stream-private.h"
+#include <mongoc/mongoc-counters-private.h>
+#include <mongoc/mongoc-gridfs-bucket-file-private.h>
+#include <mongoc/mongoc-stream-gridfs-upload-private.h>
+#include <mongoc/mongoc-stream-private.h>
+#include <mongoc/mongoc-trace-private.h>
 
 #undef MONGOC_LOG_DOMAIN
 #define MONGOC_LOG_DOMAIN "stream-gridfs-upload"
