@@ -1,5 +1,5 @@
 /*
- * Copyright 2016 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,15 +14,15 @@
  * limitations under the License.
  */
 
-#include "mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
 
 #ifndef MONGOC_STREAM_TLS_OPENSSL_H
 #define MONGOC_STREAM_TLS_OPENSSL_H
 
 #ifdef MONGOC_ENABLE_SSL_OPENSSL
-#include <bson/bson.h>
+#include <mongoc/mongoc-macros.h>
 
-#include "mongoc-macros.h"
+#include <bson/bson.h>
 
 BSON_BEGIN_DECLS
 
