@@ -1,5 +1,5 @@
 /*
- * Copyright 2014 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,17 +14,20 @@
  * limitations under the License.
  */
 
-#include "mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
 
 #ifndef MONGOC_TOPOLOGY_DESCRIPTION_PRIVATE_H
 #define MONGOC_TOPOLOGY_DESCRIPTION_PRIVATE_H
 
-#include "mongoc-set-private.h"
-#include "mongoc-server-description.h"
-#include "mongoc-array-private.h"
-#include "mongoc-topology-description.h"
-#include "mongoc-apm-private.h"
-#include "mongoc-deprioritized-servers-private.h"
+#include <mongoc/mongoc-apm-private.h>
+#include <mongoc/mongoc-array-private.h>
+#include <mongoc/mongoc-deprioritized-servers-private.h>
+#include <mongoc/mongoc-log-and-monitor-private.h>
+#include <mongoc/mongoc-server-description-private.h>
+#include <mongoc/mongoc-set-private.h>
+
+#include <mongoc/mongoc-server-description.h>
+#include <mongoc/mongoc-topology-description.h>
 
 
 typedef enum {
@@ -39,7 +42,6 @@ typedef enum {
 
 struct _mongoc_topology_description_t {
    bson_oid_t topology_id;
-   bool opened;
    mongoc_topology_description_type_t type;
    int64_t heartbeat_msec;
    mongoc_set_t *_servers_;
@@ -50,6 +52,7 @@ struct _mongoc_topology_description_t {
    uint32_t max_server_id;
    int32_t max_hosts; /* srvMaxHosts */
    bool stale;
+   bool opened;
    unsigned int rand_seed;
 
    /* the greatest seen cluster time, for a MongoDB 3.6+ sharded cluster.
@@ -59,13 +62,22 @@ struct _mongoc_topology_description_t {
    /* smallest seen logicalSessionTimeoutMinutes, or -1 if any server has no
     * logicalSessionTimeoutMinutes. see Server Discovery and Monitoring Spec */
    int64_t session_timeout_minutes;
-
-   mongoc_apm_callbacks_t apm_callbacks;
-   void *apm_context;
 };
 
 typedef enum { MONGOC_SS_READ, MONGOC_SS_WRITE, MONGOC_SS_AGGREGATE_WITH_WRITE } mongoc_ss_optype_t;
 
+/**
+ * @brief Contextual information for logging during server selection
+ *
+ * Required to support the "common fields" defined in the Server Selection Logging specification.
+ * The 'operation' string is borrowed for the lifetime of the mongoc_ss_log_context_t.
+ */
+typedef struct _mongoc_ss_log_context_t {
+   const char *operation; // Required
+   int64_t operation_id;
+   bool has_operation_id;
+} mongoc_ss_log_context_t;
+
 void
 mongoc_topology_description_init (mongoc_topology_description_t *description, int64_t heartbeat_msec);
 
@@ -96,6 +108,7 @@ mongoc_topology_description_cleanup (mongoc_topology_description_t *description)
 
 void
 mongoc_topology_description_handle_hello (mongoc_topology_description_t *topology,
+                                          const mongoc_log_and_monitor_instance_t *log_and_monitor,
                                           uint32_t server_id,
                                           const bson_t *hello_response,
                                           int64_t rtt_msec,
@@ -128,6 +141,9 @@ _mongoc_topology_description_validate_max_staleness (const mongoc_topology_descr
                                                      int64_t max_staleness_seconds,
                                                      bson_error_t *error);
 
+const mongoc_server_description_t *
+_mongoc_topology_description_has_primary (const mongoc_topology_description_t *description);
+
 void
 mongoc_topology_description_suitable_servers (mongoc_array_t *set, /* OUT */
                                               mongoc_ss_optype_t optype,
@@ -142,11 +158,13 @@ mongoc_topology_description_has_data_node (const mongoc_topology_description_t *
 
 void
 mongoc_topology_description_invalidate_server (mongoc_topology_description_t *topology,
+                                               const mongoc_log_and_monitor_instance_t *log_and_monitor,
                                                uint32_t id,
                                                const bson_error_t *error /* IN */);
 
 bool
 mongoc_topology_description_add_server (mongoc_topology_description_t *topology,
+                                        const mongoc_log_and_monitor_instance_t *log_and_monitor,
                                         const char *server,
                                         uint32_t *id /* OUT */);
 
@@ -154,7 +172,9 @@ void
 mongoc_topology_description_update_cluster_time (mongoc_topology_description_t *td, const bson_t *reply);
 
 void
-mongoc_topology_description_reconcile (mongoc_topology_description_t *td, mongoc_host_list_t *host_list);
+mongoc_topology_description_reconcile (mongoc_topology_description_t *td,
+                                       const mongoc_log_and_monitor_instance_t *log_and_monitor,
+                                       mongoc_host_list_t *host_list);
 
 /**
  * @brief Invalidate open connnections to a server.
@@ -165,7 +185,7 @@ mongoc_topology_description_reconcile (mongoc_topology_description_t *td, mongoc
  * @param td The topology description that will be updated.
  * @param server_id The ID of the server to invalidate.
  * @param service_id A service ID for load-balanced deployments. Use
- * kZeroServiceID if not applicable.
+ * kZeroObjectId if not applicable.
  *
  * @note Not applicable to single-threaded clients, which only maintain a
  * single connection per server and therefore have no connection pool.
@@ -180,4 +200,22 @@ mongoc_deprioritized_servers_add_if_sharded (mongoc_deprioritized_servers_t *ds,
                                              mongoc_topology_description_type_t topology_type,
                                              const mongoc_server_description_t *sd);
 
+typedef enum {
+   MONGOC_TOPOLOGY_DESCRIPTION_CONTENT_FLAG_TYPE = (1 << 0),
+   MONGOC_TOPOLOGY_DESCRIPTION_CONTENT_FLAG_SET_NAME = (1 << 1),
+   MONGOC_TOPOLOGY_DESCRIPTION_CONTENT_FLAG_MAX_ELECTION_ID = (1 << 2),
+   MONGOC_TOPOLOGY_DESCRIPTION_CONTENT_FLAG_MAX_SET_VERSION = (1 << 3),
+   MONGOC_TOPOLOGY_DESCRIPTION_CONTENT_FLAG_SERVERS = (1 << 4),
+   MONGOC_TOPOLOGY_DESCRIPTION_CONTENT_FLAG_STALE = (1 << 5),
+   MONGOC_TOPOLOGY_DESCRIPTION_CONTENT_FLAG_COMPATIBLE = (1 << 6),
+   MONGOC_TOPOLOGY_DESCRIPTION_CONTENT_FLAG_COMPATIBILITY_ERROR = (1 << 7),
+   MONGOC_TOPOLOGY_DESCRIPTION_CONTENT_FLAG_LOGICAL_SESSION_TIMEOUT_MINUTES = (1 << 8),
+} mongoc_topology_description_content_flags_t;
+
+bool
+mongoc_topology_description_append_contents_to_bson (const mongoc_topology_description_t *td,
+                                                     bson_t *bson,
+                                                     mongoc_topology_description_content_flags_t flags,
+                                                     mongoc_server_description_content_flags_t servers_flags);
+
 #endif /* MONGOC_TOPOLOGY_DESCRIPTION_PRIVATE_H */
