@@ -14,39 +14,47 @@
  * limitations under the License.
  */
 
-#include <bson/bson.h>
+#include <mongoc/mongoc-error-private.h>
+#include <mongoc/mongoc-handshake-private.h>
+#include <mongoc/mongoc-stream-private.h>
+#include <mongoc/mongoc-topology-scanner-private.h>
+#include <mongoc/mongoc-trace-private.h>
 
 #include <mongoc/mongoc-config.h>
-#include <mongoc/mongoc-error-private.h>
-#include <mongoc/mongoc-trace-private.h>
-#include <mongoc/mongoc-topology-scanner-private.h>
-#include <mongoc/mongoc-stream-private.h>
+#include <mongoc/mongoc-handshake.h>
 #include <mongoc/mongoc-stream-socket.h>
 
-#include <mongoc/mongoc-handshake.h>
-#include <mongoc/mongoc-handshake-private.h>
+#include <bson/bson.h>
 
 #ifdef MONGOC_ENABLE_SSL
 #include <mongoc/mongoc-stream-tls.h>
 #endif
 
 #if defined(MONGOC_ENABLE_SSL_OPENSSL) && OPENSSL_VERSION_NUMBER >= 0x10100000L
-#include <openssl/ssl.h>
 #include <mongoc/mongoc-stream-tls-private.h>
+
+#include <openssl/ssl.h>
+#endif
+
+#if defined(MONGOC_ENABLE_SSL_SECURE_CHANNEL)
+#include <mongoc/mongoc-stream-tls-private.h>
+#include <mongoc/mongoc-stream-tls-secure-channel-private.h>
 #endif
 
-#include <mongoc/mongoc-counters-private.h>
-#include <mongoc/utlist.h>
-#include <mongoc/mongoc-topology-private.h>
-#include <mongoc/mongoc-host-list-private.h>
-#include <mongoc/mongoc-uri-private.h>
-#include <mongoc/mongoc-cluster-private.h>
-#include <mongoc/mongoc-client-private.h>
-#include <mongoc/mongoc-util-private.h>
-#include <mongoc/mongoc-structured-log-private.h>
-#include <common-string-private.h>
-#include <mlib/cmp.h>
 #include <common-atomic-private.h>
+#include <common-string-private.h>
+#include <mongoc/mongoc-client-private.h>
+#include <mongoc/mongoc-cluster-private.h>
+#include <mongoc/mongoc-counters-private.h>
+#include <mongoc/mongoc-host-list-private.h>
+#include <mongoc/mongoc-structured-log-private.h>
+#include <mongoc/mongoc-topology-private.h>
+#include <mongoc/mongoc-uri-private.h>
+#include <mongoc/mongoc-util-private.h>
+
+#include <mongoc/utlist.h>
+
+#include <mlib/cmp.h>
 
 #include <inttypes.h>
 
@@ -150,6 +158,13 @@ _reset_hello (mongoc_topology_scanner_t *ts)
    _add_hello (ts);
 }
 
+void
+_mongoc_topology_scanner_node_parse_sasl_supported_mechs (const bson_t *hello, mongoc_topology_scanner_node_t *node)
+{
+   _mongoc_handshake_parse_sasl_supported_mechs (hello, &node->sasl_supported_mechs);
+   node->negotiated_sasl_supported_mechs = true;
+}
+
 const char *
 _mongoc_topology_scanner_get_speculative_auth_mechanism (const mongoc_uri_t *uri)
 {
@@ -429,6 +444,9 @@ mongoc_topology_scanner_new (const mongoc_uri_t *uri,
    /* may be overridden for testing. */
    ts->dns_cache_timeout_ms = DNS_CACHE_TIMEOUT_MS;
    bson_mutex_init (&ts->handshake_cmd_mtx);
+#if defined(MONGOC_ENABLE_SSL_SECURE_CHANNEL)
+   ts->secure_channel_cred_ptr = MONGOC_SHARED_PTR_NULL;
+#endif
 
    _init_hello (ts);
 
@@ -475,6 +493,10 @@ mongoc_topology_scanner_destroy (mongoc_topology_scanner_t *ts)
    ts->openssl_ctx = NULL;
 #endif
 
+#if defined(MONGOC_ENABLE_SSL_SECURE_CHANNEL)
+   mongoc_shared_ptr_reset_null (&ts->secure_channel_cred_ptr);
+#endif
+
    /* This field can be set by a mongoc_client */
    bson_free ((char *) ts->appname);
 
@@ -677,7 +699,7 @@ _async_success (mongoc_async_cmd_t *acmd, const bson_t *hello_response, int64_t
    }
 
    if (ts->negotiate_sasl_supported_mechs && !node->negotiated_sasl_supported_mechs) {
-      _mongoc_handshake_parse_sasl_supported_mechs (hello_response, &node->sasl_supported_mechs);
+      _mongoc_topology_scanner_node_parse_sasl_supported_mechs (hello_response, node);
    }
 
    if (ts->speculative_authentication) {
@@ -800,6 +822,9 @@ _mongoc_topology_scanner_node_setup_stream_for_tls (mongoc_topology_scanner_node
 #if defined(MONGOC_ENABLE_SSL_OPENSSL) && OPENSSL_VERSION_NUMBER >= 0x10100000L
       tls_stream = mongoc_stream_tls_new_with_hostname_and_openssl_context (
          stream, node->host.host, node->ts->ssl_opts, 1, node->ts->openssl_ctx);
+#elif defined(MONGOC_ENABLE_SSL_SECURE_CHANNEL)
+      tls_stream =
+         mongoc_stream_tls_new_with_secure_channel_cred (stream, node->ts->ssl_opts, node->ts->secure_channel_cred_ptr);
 #else
       tls_stream = mongoc_stream_tls_new_with_hostname (stream, node->host.host, node->ts->ssl_opts, 1);
 #endif
@@ -915,6 +940,7 @@ mongoc_topology_scanner_node_connect_unix (mongoc_topology_scanner_node_t *node,
 {
 #ifdef _WIN32
    ENTRY;
+   BSON_UNUSED (node);
    _mongoc_set_error (
       error, MONGOC_ERROR_STREAM, MONGOC_ERROR_STREAM_CONNECT, "UNIX domain sockets not supported on win32.");
    RETURN (false);
