@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-#include "mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
 
 #ifndef MONGOC_WRITE_CONCERN_PRIVATE_H
 #define MONGOC_WRITE_CONCERN_PRIVATE_H
@@ -25,12 +25,10 @@
 BSON_BEGIN_DECLS
 
 
-#define MONGOC_WRITE_CONCERN_FSYNC_DEFAULT -1
 #define MONGOC_WRITE_CONCERN_JOURNAL_DEFAULT -1
 
 
 struct _mongoc_write_concern_t {
-   int8_t fsync_; /* deprecated */
    int8_t journal;
    int32_t w;
    int64_t wtimeout;
