@@ -14,13 +14,16 @@
  * limitations under the License.
  */
 
-#include "bsonutil/bson-parser.h"
+#include <bsonutil/bson-parser.h>
 
-#include "unified/util.h"
-#include "test-conveniences.h"
-#include "TestSuite.h"
 #include <mongoc/utlist.h>
 
+#include <mlib/config.h>
+
+#include <TestSuite.h>
+#include <test-conveniences.h>
+#include <unified/util.h>
+
 typedef enum {
    BSON_PARSER_UTF8,
    BSON_PARSER_INT,
@@ -200,7 +203,10 @@ bson_to_read_prefs (bson_t *bson, bson_error_t *error)
    }
 
    if (hedge) {
+      mlib_diagnostic_push ();
+      mlib_disable_deprecation_warnings ();
       mongoc_read_prefs_set_hedge (out, hedge);
+      mlib_diagnostic_pop ();
    }
 
 done:
