@@ -14,12 +14,13 @@
  * limitations under the License.
  */
 
-#include <mongoc/mongoc.h>
-#include "TestSuite.h"
-#include "test-libmongoc.h"
-#include <mongoc/mongoc.h>
 #include <mongoc/mongoc-http-private.h>
+
 #include <mongoc/mongoc-uri.h>
+#include <mongoc/mongoc.h>
+
+#include <TestSuite.h>
+#include <test-libmongoc.h>
 
 
 int
