@@ -2157,21 +2157,6 @@ test_framework_skip_if_single (void)
    return (test_framework_is_mongos () || test_framework_is_replset ());
 }
 
-bool
-test_framework_is_mongohouse (void)
-{
-   return test_framework_getenv_bool ("RUN_MONGOHOUSE_TESTS");
-}
-
-int
-test_framework_skip_if_no_mongohouse (void)
-{
-   if (!test_framework_is_mongohouse ()) {
-      return 0;
-   }
-   return 1;
-}
-
 int
 test_framework_skip_if_mongos (void)
 {
@@ -2420,33 +2405,6 @@ test_framework_skip_if_no_setenv (void)
    return 1;
 }
 
-bool
-test_framework_is_serverless (void)
-{
-   return test_framework_getenv_bool ("MONGOC_TEST_IS_SERVERLESS");
-}
-
-int
-test_framework_skip_if_serverless (void)
-{
-   if (test_framework_is_serverless ()) {
-      return 0; // do not proceed
-   }
-   return 1; // proceed.
-}
-
-int
-test_framework_skip_due_to_cdriver3708 (void)
-{
-   if (0 == test_framework_skip_if_auth () && 0 == test_framework_skip_if_replset () &&
-       test_framework_get_server_version () > test_framework_str_to_version ("4.4.0")) {
-      /* If auth is enabled, we're using a replica set, and using a > 4.4
-       * server, skip test. */
-      return 0;
-   }
-   return 1;
-}
-
 static char MONGOC_TEST_UNIQUE[32];
 
 #if defined(_MSC_VER) && defined(_WIN64)
