@@ -1,5 +1,6 @@
 #include <mongoc/mongoc-array-private.h>
-#include "TestSuite.h"
+
+#include <TestSuite.h>
 
 
 static void
