@@ -1,12 +1,12 @@
-#include <mongoc/mongoc.h>
+#include <common-macros-private.h> // BEGIN_IGNORE_DEPRECATIONS
 #include <mongoc/mongoc-client-pool-private.h>
 #include <mongoc/mongoc-client-private.h>
 #include <mongoc/mongoc-util-private.h>
-#include <common-macros-private.h> // BEGIN_IGNORE_DEPRECATIONS
 
+#include <mongoc/mongoc.h>
 
-#include "TestSuite.h"
-#include "test-libmongoc.h"
+#include <TestSuite.h>
+#include <test-libmongoc.h>
 
 
 static void
