@@ -1,12 +1,13 @@
+#include <mongoc/mongoc-bulkwrite.h>
 #include <mongoc/mongoc.h>
 
-#include "json-test.h"
-#include "json-test-operations.h"
-#include "test-libmongoc.h"
-#include <mongoc/mongoc-bulkwrite.h>
 #include <mlib/cmp.h>
 #include <mlib/loop.h>
 
+#include <json-test-operations.h>
+#include <json-test.h>
+#include <test-libmongoc.h>
+
 static bool
 crud_test_operation_cb (json_test_ctx_t *ctx, const bson_t *test, const bson_t *operation)
 {
@@ -1431,8 +1432,7 @@ test_crud_install (TestSuite *suite)
                       prose_test_1,
                       NULL, /* dtor */
                       NULL, /* ctx */
-                      test_framework_skip_if_no_failpoint,
-                      test_framework_skip_if_max_wire_version_less_than_7);
+                      test_framework_skip_if_no_failpoint);
 
    TestSuite_AddFull (suite,
                       "/crud/prose_test_2",
