@@ -1,15 +1,16 @@
-#include <bson/bcon.h>
-#include <mongoc/mongoc.h>
+#include <mongoc/mongoc-client-private.h>
 #include <mongoc/mongoc-collection-private.h>
 #include <mongoc/mongoc-find-and-modify-private.h>
-#include <mongoc/mongoc-client-private.h>
 
-#include "TestSuite.h"
+#include <mongoc/mongoc.h>
 
-#include "test-libmongoc.h"
-#include "test-conveniences.h"
-#include "mock_server/future-functions.h"
-#include "mock_server/mock-server.h"
+#include <bson/bson-bcon.h>
+
+#include <TestSuite.h>
+#include <mock_server/future-functions.h>
+#include <mock_server/mock-server.h>
+#include <test-conveniences.h>
+#include <test-libmongoc.h>
 
 static void
 auto_hello (mock_server_t *server,
