@@ -1,12 +1,14 @@
-#include "mock_server/mock-server.h"
-#include "mock_server/future.h"
-#include "mock_server/future-functions.h"
-#include <mongoc/mongoc.h>
 #include <mongoc/mongoc-gridfs-bucket-private.h>
-#include "json-test.h"
-#include "TestSuite.h"
-#include "test-conveniences.h"
-#include "test-libmongoc.h"
+
+#include <mongoc/mongoc.h>
+
+#include <TestSuite.h>
+#include <json-test.h>
+#include <mock_server/future-functions.h>
+#include <mock_server/future.h>
+#include <mock_server/mock-server.h>
+#include <test-conveniences.h>
+#include <test-libmongoc.h>
 
 void
 test_create_bucket (void)
