@@ -1,15 +1,14 @@
+#include <common-oid-private.h>
+#include <mongoc/mongoc-client-private.h>
+#include <mongoc/mongoc-set-private.h>
+#include <mongoc/mongoc-socket-private.h>
+#include <mongoc/mongoc-topology-description-apm-private.h>
+#include <mongoc/mongoc-topology-private.h>
+
 #include <mongoc/mongoc.h>
 
-#include <mongoc/mongoc-set-private.h>
-#include <common-oid-private.h>
-
-#include "json-test.h"
-
-#include <mongoc/mongoc-socket-private.h>
-#include <mongoc/mongoc-client-private.h>
-#include <mongoc/mongoc-topology-private.h>
-#include <mongoc/mongoc-topology-description-apm-private.h>
-#include "test-libmongoc.h"
+#include <json-test.h>
+#include <test-libmongoc.h>
 
 #ifdef BSON_HAVE_STRINGS_H
 #include <strings.h>
@@ -153,6 +152,19 @@ test_sdam_cb (void *test_vp)
    BSON_ASSERT_PARAM (test_vp);
    const bson_t *const test = test_vp;
 
+   static const test_skip_t skips[] = {
+      {.description = "Pre-4.2",
+       .check_substring = true,
+       .reason = "libmongoc does not support servers older than 4.2"},
+      {0} // NULL terminated.
+   };
+
+   BSON_ASSERT (bson_iter_init_find (&iter, test, "description"));
+   const char *description = bson_iter_utf8 (&iter, NULL);
+   if (test_should_be_skipped (skips, description)) {
+      return;
+   }
+
    /* parse out the uri and use it to create a client */
    BSON_ASSERT (bson_iter_init_find (&iter, test, "uri"));
    client = test_framework_client_new (bson_iter_utf8 (&iter, NULL), NULL);
