@@ -1,7 +1,7 @@
-#include "TestSuite.h"
-
 #include <mongoc/mongoc-shared-private.h>
 
+#include <TestSuite.h>
+
 typedef struct {
    int value;
    int *store_value_on_dtor;
