@@ -14,11 +14,11 @@
  * limitations under the License.
  */
 
-#include "TestSuite.h"
-#include "test-libmongoc.h"
-
 #include <mongoc/mongoc-timeout-private.h>
 
+#include <TestSuite.h>
+#include <test-libmongoc.h>
+
 void
 _test_mongoc_timeout_new_success (int64_t expected)
 {
