@@ -1,17 +1,17 @@
-#include <mongoc/mongoc.h>
-
-#include <mongoc/mongoc-client-private.h>
+#include <common-atomic-private.h>
 #include <mongoc/mongoc-client-pool-private.h>
+#include <mongoc/mongoc-client-private.h>
 #include <mongoc/mongoc-util-private.h>
+
+#include <mongoc/mongoc.h>
 #include <mongoc/utlist.h>
 
-#include "mock_server/future.h"
-#include "mock_server/future-functions.h"
-#include "mock_server/mock-server.h"
-#include "TestSuite.h"
-#include "test-conveniences.h"
-#include "test-libmongoc.h"
-#include <common-atomic-private.h>
+#include <TestSuite.h>
+#include <mock_server/future-functions.h>
+#include <mock_server/future.h>
+#include <mock_server/mock-server.h>
+#include <test-conveniences.h>
+#include <test-libmongoc.h>
 
 
 static mongoc_topology_scanner_node_t *
