@@ -14,26 +14,28 @@
  * limitations under the License.
  */
 
-#include "entity-map.h"
-
-#include "bsonutil/bson-parser.h"
-#include "TestSuite.h"
-#include <mongoc/mongoc.h>
-#include "test-conveniences.h"
-#include "test-libmongoc.h"
-#include <mongoc/utlist.h>
-#include "util.h"
-
-#include <common-bson-dsl-private.h>
+#include "./entity-map.h"
+#include "./util.h"
 
 #include <common-b64-private.h>
+#include <common-bson-dsl-private.h>
 #include <mongoc/mongoc-client-side-encryption-private.h>
 
+#include <mongoc/mongoc.h>
+#include <mongoc/utlist.h>
+
+#include <bson/bson.h>
+#include <bsonutil/bson-parser.h>
+
+#include <TestSuite.h>
+#include <test-conveniences.h>
+#include <test-libmongoc.h>
+
 /* TODO: use public API to reduce min heartbeat once CDRIVER-3130 is resolved.
  */
+#include <common-string-private.h>
 #include <mongoc/mongoc-client-private.h>
 #include <mongoc/mongoc-topology-private.h>
-#include <common-string-private.h>
 
 #define REDUCED_HEARTBEAT_FREQUENCY_MS 500
 #define REDUCED_MIN_HEARTBEAT_FREQUENCY_MS 50
@@ -48,6 +50,9 @@ typedef void (*event_serialize_func_t) (bson_t *bson, const void *event);
 static void
 entity_destroy (entity_t *entity);
 
+static bool
+_parse_and_set_auto_encryption_opts (mongoc_client_t *client, bson_t *opts, bson_error_t *error);
+
 entity_map_t *
 entity_map_new (void)
 {
@@ -135,9 +140,10 @@ done:
    return ret;
 }
 
-/* Consider refactoring the names, this is confusing. "type" has been the name of the specific event
- * type. "eventType" is more like what's called the "component" in structured logging, but here it's
- * named after the field in expectedEventsForClient. */
+/* Consider refactoring the names, this is confusing. "type" has been the name
+ * of the specific event type. "eventType" is more like what's called the
+ * "component" in structured logging, but here it's named after the field in
+ * expectedEventsForClient. */
 static event_t *
 event_new (const char *type, const char *eventType, bson_t *serialized, bool is_sensitive_command)
 {
@@ -179,7 +185,8 @@ event_destroy (event_t *event)
 
 /**
  * @brief Test whether a structured log entry is accepted by all active filters
- * @returns true if all filters have returned true in response to this entry, or if no filters were active
+ * @returns true if all filters have returned true in response to this entry, or
+ * if no filters were active
  * @param entity Client entity with the filter stack to query
  * @param entry Borrowed constant reference to the log entry
  *
@@ -201,7 +208,8 @@ _entity_log_filter_accepts (const entity_t *entity, const mongoc_structured_log_
 /**
  * @brief Push a new structured log filter function onto the stack
  * @param entity Client entity to modify the filter stack for
- * @param func Filter function, returns true to accept a log or false to reject. May be NULL to reject all logs.
+ * @param func Filter function, returns true to accept a log or false to reject.
+ * May be NULL to reject all logs.
  * @param user_data Optional user_data pointer, passed to 'func'.
  *
  * Must be paired with entity_log_filter_pop.
@@ -225,10 +233,13 @@ entity_log_filter_push (entity_t *entity, log_filter_func_t *func, void *user_da
 }
 
 /**
- * @brief Pop the most recent structured log filter from the stack, which must match
+ * @brief Pop the most recent structured log filter from the stack, which must
+ * match
  * @param entity Client entity to modify the filter stack for
- * @param func Filter function, must match the value given to entity_log_filter_push
- * @param user_data Must match the corresponding user_data value from entity_log_filter_push
+ * @param func Filter function, must match the value given to
+ * entity_log_filter_push
+ * @param user_data Must match the corresponding user_data value from
+ * entity_log_filter_push
  *
  * Briefly acquires log_mutex.
  */
@@ -724,6 +735,7 @@ entity_client_new (entity_map_t *em, bson_t *bson, bson_error_t *error)
    bool ret = false;
    mongoc_apm_callbacks_t *callbacks = NULL;
    bson_t *uri_options = NULL;
+   bson_t *auto_encryption_opts = NULL;
    mongoc_structured_log_opts_t *log_opts = mongoc_structured_log_opts_new ();
    bool use_multiple_mongoses = false;
    bool use_multiple_mongoses_set = false;
@@ -743,19 +755,19 @@ entity_client_new (entity_map_t *em, bson_t *bson, bson_error_t *error)
       else (error ("A client 'id' string is required")),
       // Optional 'uriOptions' for the client
       find (key ("uriOptions"),
-            if (not(type (doc)), then (error ("'uriOptions' must be a document value"))),
+            if (not (type (doc)), then (error ("'uriOptions' must be a document value"))),
             storeDocDupPtr (uri_options)),
       // Optional 'useMultipleMongoses' bool
       find (key ("useMultipleMongoses"),
-            if (not(type (boolean)), then (error ("'useMultipleMongoses' must be a bool value"))),
+            if (not (type (boolean)), then (error ("'useMultipleMongoses' must be a bool value"))),
             do (use_multiple_mongoses_set = true),
             storeBool (use_multiple_mongoses)),
       // Events to observe:
       find (key ("observeEvents"),
-            if (not(type (array)), then (error ("'observeEvents' must be an array"))),
+            if (not (type (array)), then (error ("'observeEvents' must be an array"))),
             visitEach (case (
                // Ensure all elements are strings:
-               when (not(type (utf8)), error ("Every 'observeEvents' element must be a string")),
+               when (not (type (utf8)), error ("Every 'observeEvents' element must be a string")),
                // Dispatch based on the event name:
                when (eval (is_supported_event_type (bson_iter_utf8 (&bsonVisitIter, NULL))), do ({
                         const char *const type = bson_iter_utf8 (&bsonVisitIter, NULL);
@@ -769,14 +781,14 @@ entity_client_new (entity_map_t *em, bson_t *bson, bson_error_t *error)
                else (do (test_error ("Unknown event type '%s'", bsonAs (cstr))))))),
       // Command events to ignore
       find (key ("ignoreCommandMonitoringEvents"),
-            if (not(type (array)), then (error ("'ignoreCommandMonitoringEvents' must be an array"))),
-            visitEach (if (not(type (utf8)),
+            if (not (type (array)), then (error ("'ignoreCommandMonitoringEvents' must be an array"))),
+            visitEach (if (not (type (utf8)),
                            then (error ("Every 'ignoreCommandMonitoringEvents' "
                                         "element must be a string")))),
             storeDocDupPtr (entity->ignore_command_monitoring_events)),
       // Parse the serverApi, if present
       find (key ("serverApi"),
-            if (not(type (doc)), then (error ("'serverApi' must be a document"))),
+            if (not (type (doc)), then (error ("'serverApi' must be a document"))),
             parse ( // The "version" string is required first:
                find (keyWithType ("version", utf8), do ({
                         mongoc_server_api_version_t ver;
@@ -789,49 +801,54 @@ entity_client_new (entity_map_t *em, bson_t *bson, bson_error_t *error)
                else (error ("Missing 'version' property in 'serverApi' object")),
                // Toggle strictness:
                find (key ("strict"),
-                     if (not(type (boolean)), then (error ("'serverApi.strict' must be a bool"))),
+                     if (not (type (boolean)), then (error ("'serverApi.strict' must be a bool"))),
                      do (mongoc_server_api_strict (api, bsonAs (boolean)))),
                // Toggle deprecation errors:
                find (key ("deprecationErrors"),
-                     if (not(type (boolean)), then (error ("serverApi.deprecationErrors must be a bool"))),
+                     if (not (type (boolean)), then (error ("serverApi.deprecationErrors must be a bool"))),
                      do (mongoc_server_api_deprecation_errors (api, bsonAs (boolean)))))),
       // Toggle observation of sensitive commands
       find (key ("observeSensitiveCommands"),
-            if (not(type (boolean)), then (error ("'observeSensitiveCommands' must be a bool"))),
+            if (not (type (boolean)), then (error ("'observeSensitiveCommands' must be a bool"))),
             do ({
                bool *p = entity->observe_sensitive_commands = bson_malloc (sizeof (bool));
                *p = bsonAs (boolean);
             })),
       // Which events should be available as entities:
-      find (
-         key ("storeEventsAsEntities"),
-         if (not(type (array)), then (error ("'storeEventsAsEntities' must be an array"))),
-         visitEach (parse (
-            find (keyWithType ("id", utf8), storeStrRef (store_entity_id), do ({
-                     if (!entity_map_add_bson_array (em, store_entity_id, error)) {
-                        test_error ("failed to create storeEventsAsEntities "
-                                    "entity '%s': %s",
-                                    store_entity_id,
-                                    error->message);
-                     }
-                  })),
-            find (keyWithType ("events", array),
-                  visitEach (case (when (not(type (utf8)),
-                                         error ("Every 'storeEventsAsEntities.events' "
-                                                "element must be a string")),
-                                   when (eval (is_supported_event_type (bson_iter_utf8 (&bsonVisitIter, NULL))), do ({
-                                            const char *const type = bson_iter_utf8 (&bsonVisitIter, NULL);
-                                            set_event_callback (callbacks, type);
-                                            add_store_event (entity, type, store_entity_id);
-                                         })),
-                                   when (eval (is_unsupported_event_type (bson_iter_utf8 (&bsonVisitIter, NULL))),
-                                         do (MONGOC_DEBUG ("Skipping unsupported event type '%s'", bsonAs (cstr)))),
-                                   else (do (test_error ("Unknown event type '%s'", bsonAs (cstr))))))),
-            visitOthers (
-               errorf (err, "Unexpected field '%s' in storeEventsAsEntities", bson_iter_key (&bsonVisitIter)))))),
+      find (key ("storeEventsAsEntities"),
+            if (not (type (array)), then (error ("'storeEventsAsEntities' must be an array"))),
+            visitEach (parse (
+               find (keyWithType ("id", utf8), storeStrRef (store_entity_id), do ({
+                        if (!entity_map_add_bson_array (em, store_entity_id, error)) {
+                           test_error ("failed to create storeEventsAsEntities "
+                                       "entity '%s': %s",
+                                       store_entity_id,
+                                       error->message);
+                        }
+                     })),
+               find (keyWithType ("events", array),
+                     visitEach (case (when (not (type (utf8)),
+                                            error ("Every 'storeEventsAsEntities.events' "
+                                                   "element must be a string")),
+                                      when (anyOf (iStrEqual ("commandStartedEvent"),
+                                                   iStrEqual ("commandFailedEvent"),
+                                                   iStrEqual ("commandSucceededEvent")),
+                                            do ({
+                                               const char *const type = bson_iter_utf8 (&bsonVisitIter, NULL);
+                                               set_event_callback (callbacks, type);
+                                               add_store_event (entity, type, store_entity_id);
+                                            })),
+                                      when (eval (is_unsupported_event_type (bson_iter_utf8 (&bsonVisitIter, NULL))),
+                                            do (MONGOC_DEBUG ("Skipping unsupported event type '%s'", bsonAs (cstr)))),
+                                      else (do (test_error ("Unknown event type '%s'", bsonAs (cstr))))))),
+               visitOthers (
+                  errorf (err, "Unexpected field '%s' in storeEventsAsEntities", bson_iter_key (&bsonVisitIter)))))),
+      find (key ("autoEncryptOpts"),
+            if (not (type (doc)), then (error ("'autoEncryptOpts' must be a document value"))),
+            storeDocDupPtr (auto_encryption_opts)),
       // Log messages to observe:
       find (key ("observeLogMessages"),
-            if (not(type (doc)), then (error ("'observeLogMessages' must be a document"))),
+            if (not (type (doc)), then (error ("'observeLogMessages' must be a document"))),
             do ({
                // Initialize all components to the lowest available level, and install a handler.
                BSON_ASSERT (mongoc_structured_log_opts_set_max_level_for_all_components (
@@ -842,7 +859,7 @@ entity_client_new (entity_map_t *em, bson_t *bson, bson_error_t *error)
                mongoc_structured_log_opts_set_max_document_length (log_opts, 10000);
             }),
             visitEach (
-               if (not(type (utf8)), then (error ("Every value in 'observeLogMessages' must be a log level string"))),
+               if (not (type (utf8)), then (error ("Every value in 'observeLogMessages' must be a log level string"))),
                do ({
                   const char *const component_name = bson_iter_key (&bsonVisitIter);
                   mongoc_structured_log_component_t component;
@@ -914,6 +931,12 @@ entity_client_new (entity_map_t *em, bson_t *bson, bson_error_t *error)
       client->topology->min_heartbeat_frequency_msec = REDUCED_MIN_HEARTBEAT_FREQUENCY_MS;
    }
 
+   if (auto_encryption_opts) {
+      if (!_parse_and_set_auto_encryption_opts (client, auto_encryption_opts, error)) {
+         goto done;
+      }
+   }
+
    ret = true;
 done:
    mongoc_uri_destroy (uri);
@@ -921,6 +944,7 @@ done:
    mongoc_server_api_destroy (api);
    mongoc_structured_log_opts_destroy (log_opts);
    bson_destroy (uri_options);
+   bson_destroy (auto_encryption_opts);
    if (!ret) {
       entity_destroy (entity);
       return NULL;
@@ -1232,8 +1256,13 @@ _parse_kms_provider_local (
 }
 
 static bool
-_parse_and_set_kms_providers (mongoc_client_encryption_opts_t *ce_opts, bson_t *kms_from_file, bson_error_t *error)
+_get_kms_providers_docs (bson_t *kms_from_file, bson_t *kms_providers, bson_t *tls_opts, bson_error_t *error)
 {
+   BSON_ASSERT_PARAM (kms_from_file);
+   BSON_ASSERT_PARAM (kms_providers);
+   BSON_ASSERT_PARAM (tls_opts);
+   BSON_OPTIONAL_PARAM (error);
+
    /* Map provider to corresponding KMS parser. */
    typedef struct _prov_map_t {
       const char *provider;
@@ -1255,10 +1284,6 @@ _parse_and_set_kms_providers (mongoc_client_encryption_opts_t *ce_opts, bson_t *
                                   {.provider = "local:name2", .parse = _parse_kms_provider_local}};
 
    const size_t prov_map_size = sizeof (prov_map) / sizeof (prov_map[0]);
-
-   bool ret = false;
-   bson_t kms_providers = BSON_INITIALIZER;
-   bson_t tls_opts = BSON_INITIALIZER;
    bson_iter_t iter;
 
    BSON_FOREACH (kms_from_file, iter)
@@ -1270,12 +1295,12 @@ _parse_and_set_kms_providers (mongoc_client_encryption_opts_t *ce_opts, bson_t *
 
       if (!bson_init_from_value (&kms_doc, bson_iter_value (&iter))) {
          test_set_error (error, "kmsProviders field '%s' is not a valid document", provider);
-         goto done;
+         return false;
       }
 
       for (i = 0u; i < prov_map_size; ++i) {
          if (strcmp (provider, prov_map[i].provider) == 0) {
-            found = prov_map[i].parse (&kms_providers, &tls_opts, provider, &kms_doc, error);
+            found = prov_map[i].parse (kms_providers, tls_opts, provider, &kms_doc, error);
             goto parsed;
          }
       }
@@ -1286,13 +1311,137 @@ _parse_and_set_kms_providers (mongoc_client_encryption_opts_t *ce_opts, bson_t *
       bson_destroy (&kms_doc);
 
       if (!found) {
-         goto done;
+         return false;
       }
    }
+   return true;
+}
 
+static void
+maybe_set_extra_crypt_shared (bson_t *extra)
+{
+   if (bson_has_field (extra, "cryptSharedLibPath")) {
+      return; // Already set.
+   }
+
+   char *const path = test_framework_getenv ("MONGOC_TEST_CRYPT_SHARED_LIB_PATH");
+   if (path) {
+      BSON_APPEND_UTF8 (extra, "cryptSharedLibPath", path);
+      bson_free (path);
+   }
+}
+
+static bool
+_parse_and_set_auto_encryption_opts (mongoc_client_t *client, bson_t *opts, bson_error_t *error)
+{
+   bool ret = false;
+   mongoc_auto_encryption_opts_t *auto_encryption_opts = mongoc_auto_encryption_opts_new ();
+   bson_t kms_providers = BSON_INITIALIZER;
+   bson_t tls_opts = BSON_INITIALIZER;
+   BSON_ASSERT (client);
+   bson_t *extra = NULL;
+
+   bson_parser_t *const parser = bson_parser_new ();
+
+   bson_t *kms_providers_raw;
+   bson_parser_doc (parser, "kmsProviders", &kms_providers_raw);
+
+   char *keyvault_ns;
+   bson_parser_utf8 (parser, "keyVaultNamespace", &keyvault_ns);
+
+   bson_t *schema_map;
+   bson_parser_doc_optional (parser, "schemaMap", &schema_map);
+
+   bool *bypass_auto_encryption;
+   bson_parser_bool_optional (parser, "bypassAutoEncryption", &bypass_auto_encryption);
+
+   bool *bypass_query_analysis;
+   bson_parser_bool_optional (parser, "bypassQueryAnalysis", &bypass_query_analysis);
+
+   bson_t *encrypted_fields_map;
+   bson_parser_doc_optional (parser, "encryptedFieldsMap", &encrypted_fields_map);
+
+   int64_t *key_expiration_ms;
+   bson_parser_int_optional (parser, "keyExpirationMS", &key_expiration_ms);
+
+   bson_t *extra_options;
+   bson_parser_doc_optional (parser, "extraOptions", &extra_options);
+
+   if (!bson_parser_parse (parser, opts, error)) {
+      goto done;
+   }
+
+   {
+      if (!_get_kms_providers_docs (kms_providers_raw, &kms_providers, &tls_opts, error)) {
+         goto done;
+      }
+      mongoc_auto_encryption_opts_set_kms_providers (auto_encryption_opts, &kms_providers);
+      mongoc_auto_encryption_opts_set_tls_opts (auto_encryption_opts, &tls_opts);
+   }
+
+   {
+      // keyVaultNamespace
+      char *dot = strstr (keyvault_ns, ".");
+      BSON_ASSERT (dot);
+      char *db_name = bson_strndup (keyvault_ns, dot - keyvault_ns);
+      char *coll_name = bson_strdup (dot + 1);
+      mongoc_auto_encryption_opts_set_keyvault_namespace (auto_encryption_opts, db_name, coll_name);
+
+      bson_free (db_name);
+      bson_free (coll_name);
+   }
+
+   if (schema_map) {
+      mongoc_auto_encryption_opts_set_schema_map (auto_encryption_opts, schema_map);
+   }
+
+   if (bypass_auto_encryption) {
+      mongoc_auto_encryption_opts_set_bypass_auto_encryption (auto_encryption_opts, *bypass_auto_encryption);
+   }
+
+   if (bypass_query_analysis) {
+      mongoc_auto_encryption_opts_set_bypass_query_analysis (auto_encryption_opts, *bypass_query_analysis);
+   }
+
+   if (encrypted_fields_map) {
+      mongoc_auto_encryption_opts_set_encrypted_fields_map (auto_encryption_opts, encrypted_fields_map);
+   }
+
+   if (key_expiration_ms) {
+      mongoc_auto_encryption_opts_set_key_expiration (auto_encryption_opts, *key_expiration_ms);
+   }
+
+   if (extra_options) {
+      extra = bson_copy (extra_options);
+      maybe_set_extra_crypt_shared (extra);
+      mongoc_auto_encryption_opts_set_extra (auto_encryption_opts, extra);
+   }
+
+   if (!mongoc_client_enable_auto_encryption (client, auto_encryption_opts, error)) {
+      goto done;
+   }
+   ret = true;
+
+done:
+   bson_destroy (extra);
+   mongoc_auto_encryption_opts_destroy (auto_encryption_opts);
+   bson_destroy (&kms_providers);
+   bson_destroy (&tls_opts);
+   bson_parser_destroy_with_parsed_fields (parser);
+   return ret;
+}
+
+static bool
+_parse_and_set_kms_providers (mongoc_client_encryption_opts_t *ce_opts, bson_t *kms_from_file, bson_error_t *error)
+{
+   bool ret = false;
+   bson_t kms_providers = BSON_INITIALIZER;
+   bson_t tls_opts = BSON_INITIALIZER;
+   if (!_get_kms_providers_docs (kms_from_file, &kms_providers, &tls_opts, error)) {
+      goto done;
+   }
    mongoc_client_encryption_opts_set_kms_providers (ce_opts, &kms_providers);
    mongoc_client_encryption_opts_set_tls_opts (ce_opts, &tls_opts);
-
    ret = true;
 
 done:
@@ -1413,6 +1562,7 @@ typedef struct {
    mongoc_read_concern_t *rc;
    mongoc_write_concern_t *wc;
    mongoc_read_prefs_t *rp;
+   bson_t *encrypted_fields;
 } coll_or_db_opts_t;
 
 static coll_or_db_opts_t *
@@ -1430,6 +1580,7 @@ coll_or_db_opts_destroy (coll_or_db_opts_t *opts)
    mongoc_read_concern_destroy (opts->rc);
    mongoc_read_prefs_destroy (opts->rp);
    mongoc_write_concern_destroy (opts->wc);
+   bson_destroy (opts->encrypted_fields);
    bson_free (opts);
 }
 
@@ -1651,7 +1802,10 @@ done:
 }
 
 entity_t *
-entity_session_new (entity_map_t *entity_map, bson_t *bson, bson_error_t *error)
+entity_session_new (entity_map_t *entity_map,
+                    bson_t *bson,
+                    const bson_t *cluster_time_after_initial_data,
+                    bson_error_t *error)
 {
    bson_parser_t *parser = NULL;
    entity_t *entity = NULL;
@@ -1691,6 +1845,9 @@ entity_session_new (entity_map_t *entity_map, bson_t *bson, bson_error_t *error)
    if (!session) {
       goto done;
    }
+   if (cluster_time_after_initial_data) {
+      mongoc_client_session_advance_cluster_time (session, cluster_time_after_initial_data);
+   }
    entity->value = session;
    /* Ending a session destroys the session object.
     * After a session is ended, match assertions may be made on the lsid.
@@ -1785,7 +1942,10 @@ done:
  * object immediately.
  */
 bool
-entity_map_create (entity_map_t *entity_map, bson_t *bson, bson_error_t *error)
+entity_map_create (entity_map_t *entity_map,
+                   bson_t *bson,
+                   const bson_t *cluster_time_after_initial_data,
+                   bson_error_t *error)
 {
    bson_iter_t iter;
    const char *entity_type;
@@ -1816,7 +1976,7 @@ entity_map_create (entity_map_t *entity_map, bson_t *bson, bson_error_t *error)
    } else if (0 == strcmp (entity_type, "collection")) {
       entity = entity_collection_new (entity_map, &entity_bson, error);
    } else if (0 == strcmp (entity_type, "session")) {
-      entity = entity_session_new (entity_map, &entity_bson, error);
+      entity = entity_session_new (entity_map, &entity_bson, cluster_time_after_initial_data, error);
    } else if (0 == strcmp (entity_type, "bucket")) {
       entity = entity_bucket_new (entity_map, &entity_bson, error);
    } else {
