@@ -14,19 +14,28 @@
  * limitations under the License.
  */
 
-#include "bsonutil/bson-parser.h"
-#include "entity-map.h"
-#include "json-test.h"
-#include "operation.h"
-#include "runner.h"
-#include "test-conveniences.h"
-#include "test-libmongoc.h"
-#include "test-diagnostics.h"
-#include <mongoc/utlist.h>
-#include "util.h"
-#include <common-string-private.h>
-#include <mlib/cmp.h>
+#include "./entity-map.h"
+#include "./operation.h"
+#include "./runner.h"
+#include "./test-diagnostics.h"
+#include "./util.h"
+
 #include <common-oid-private.h>
+#include <common-string-private.h>
+#include <mongoc/mongoc-database-private.h>
+
+#include <mongoc/utlist.h>
+
+#include <bson/bson.h>
+#include <bsonutil/bson-match.h>
+#include <bsonutil/bson-parser.h>
+#include <bsonutil/bson-val.h>
+
+#include <mlib/cmp.h>
+
+#include <json-test.h>
+#include <test-conveniences.h>
+#include <test-libmongoc.h>
 
 typedef struct {
    const char *file_description;
@@ -44,11 +53,6 @@ skipped_unified_test_t SKIPPED_TESTS[] = {
    {"snapshot-sessions", "Distinct operation with snapshot"},
    {"snapshot-sessions", "Mixed operation with snapshot"},
 
-   // CDRIVER-3886: serverless testing (schema version 1.4)
-   {"poc-crud", SKIP_ALL_TESTS},
-   {"db-aggregate", SKIP_ALL_TESTS},
-   {"mongos-unpin", SKIP_ALL_TESTS},
-
    // CDRIVER-2871: CMAP is not implemented
    {"assertNumberConnectionsCheckedOut", SKIP_ALL_TESTS},
    {"entity-client-cmap-events", SKIP_ALL_TESTS},
@@ -323,10 +327,7 @@ test_runner_terminate_open_transactions (test_runner_t *test_runner, bson_error_
    bool cmd_ret = false;
    bson_error_t cmd_error = {0};
 
-   if (test_framework_getenv_bool ("MONGOC_TEST_ATLAS")) {
-      // Not applicable when running as test-atlas-executor.
-      return true;
-   } else if (0 == test_framework_skip_if_no_txns ()) {
+   if (0 == test_framework_skip_if_no_txns ()) {
       ret = true;
       goto done;
    }
@@ -383,9 +384,6 @@ test_runner_new (void)
 {
    bson_error_t error;
 
-   // Avoid executing unnecessary commands when running as test-atlas-executor.
-   const bool is_atlas = test_framework_getenv_bool ("MONGOC_TEST_ATLAS");
-
    test_runner_t *const test_runner = bson_malloc0 (sizeof (test_runner_t));
 
    _mongoc_array_init (&test_runner->server_ids, sizeof (uint32_t));
@@ -393,10 +391,9 @@ test_runner_new (void)
    {
       mongoc_uri_t *const uri = test_framework_get_uri ();
 
-
       /* In load balanced mode, the internal client must use the
        * SINGLE_LB_MONGOS_URI. */
-      if (!is_atlas && !test_framework_is_loadbalanced ()) {
+      if (!test_framework_is_loadbalanced ()) {
          /* Always use multiple mongoses if speaking to a mongos.
           * Some test operations require communicating with all known mongos */
          if (!test_framework_uri_apply_multi_mongos (uri, true, &error)) {
@@ -423,8 +420,6 @@ test_runner_new (void)
    test_runner->topology_type = get_topology_type (test_runner->internal_client);
    server_semver (test_runner->internal_client, &test_runner->server_version);
 
-   test_runner->is_serverless = test_framework_is_serverless ();
-
    /* Terminate any possible open transactions. */
    if (!test_runner_terminate_open_transactions (test_runner, &error)) {
       test_error ("error terminating transactions: %s", error.message);
@@ -532,6 +527,7 @@ test_destroy (test_t *test)
    bson_destroy (test->run_on_requirements);
    bson_free (test->description);
    bson_free (test->skip_reason);
+   bson_destroy (test->cluster_time_after_initial_data);
    bson_free (test);
 }
 
@@ -557,7 +553,6 @@ is_sharded (bson_t *hello_reply)
       return false;
    }
 
-
    val = bson_lookup_utf8 (hello_reply, "msg");
    if (0 == strcmp (val, "isdbgrid")) {
       return true;
@@ -635,8 +630,9 @@ check_schema_version (test_file_t *test_file)
    // 1.18 is partially supported (additional properties in kmsProviders)
    // 1.21 is partially supported (expectedError.writeErrors and expectedError.writeConcernErrors)
    // 1.22 is partially supported (keyExpirationMS in client encryption options)
+   // 1.23 is partially supported (automatic encryption)
    semver_t schema_version;
-   semver_parse ("1.22", &schema_version);
+   semver_parse ("1.23", &schema_version);
 
    if (schema_version.major != test_file->schema_version.major) {
       goto fail;
@@ -738,28 +734,7 @@ check_run_on_requirement (test_runner_t *test_runner,
       }
 
       if (0 == strcmp (key, "serverless")) {
-         const char *serverless_mode = bson_iter_utf8 (&req_iter, NULL);
-
-         if (0 == strcmp (serverless_mode, "allow")) {
-            continue;
-         } else if (0 == strcmp (serverless_mode, "require")) {
-            if (!test_runner->is_serverless) {
-               *fail_reason = bson_strdup_printf ("Not running in serverless mode");
-               return false;
-            }
-
-            continue;
-         } else if (0 == strcmp (serverless_mode, "forbid")) {
-            if (test_runner->is_serverless) {
-               *fail_reason = bson_strdup_printf ("Running in serverless mode");
-               return false;
-            }
-
-            continue;
-         } else {
-            test_error ("Unexpected serverless mode: %s", serverless_mode);
-         }
-
+         // Ignore deprecated serverless runOnRequirement. Serverless is not tested.
          continue;
       }
 
@@ -790,6 +765,11 @@ check_run_on_requirement (test_runner_t *test_runner,
             return false;
          }
 
+         if (0 == test_framework_skip_if_no_client_side_encryption ()) {
+            *fail_reason = bson_strdup ("CSFLE is required but not all environment variables are set");
+            return false;
+         }
+
          if (csfle_required) {
             continue;
          }
@@ -866,8 +846,27 @@ test_setup_initial_data (test_t *test, bson_error_t *error)
    test_file = test->test_file;
    test_runner = test_file->test_runner;
 
+   mongoc_client_session_t *sess = mongoc_client_start_session (test_runner->internal_client, NULL, error);
+   if (sess == NULL) {
+      return false;
+   }
+
    if (!test_file->initial_data) {
-      return true;
+      // Send a "ping" command with the session to get a cluster time.
+      bson_t opts = BSON_INITIALIZER;
+      bool ok = mongoc_client_session_append (sess, &opts, error);
+      ok = ok && mongoc_client_command_with_opts (
+                    test_runner->internal_client, "db", tmp_bson ("{'ping': 1}"), NULL, &opts, NULL, error);
+      if (ok) {
+         // Check for cluster time (not available on standalone).
+         const bson_t *ct = mongoc_client_session_get_cluster_time (sess);
+         if (ct) {
+            test->cluster_time_after_initial_data = bson_copy (ct);
+         }
+      }
+      mongoc_client_session_destroy (sess);
+      bson_destroy (&opts);
+      return ok;
    }
 
    BSON_FOREACH (test_file->initial_data, initial_data_iter)
@@ -883,7 +882,7 @@ test_setup_initial_data (test_t *test, bson_error_t *error)
       mongoc_write_concern_t *wc = NULL;
       bson_t *bulk_opts = NULL;
       bson_t *drop_opts = bson_new ();
-      bson_t *create_opts = bson_new ();
+      bson_t *create_opts = NULL;
       bool ret = false;
 
       bson_iter_bson (&initial_data_iter, &collection_data);
@@ -891,14 +890,22 @@ test_setup_initial_data (test_t *test, bson_error_t *error)
       bson_parser_utf8 (parser, "databaseName", &database_name);
       bson_parser_utf8 (parser, "collectionName", &collection_name);
       bson_parser_array (parser, "documents", &documents);
+      bson_parser_doc_optional (parser, "createOptions", &create_opts);
       if (!bson_parser_parse (parser, &collection_data, error)) {
          goto loopexit;
       }
 
+      if (create_opts == NULL) {
+         create_opts = bson_new ();
+      }
+
       wc = mongoc_write_concern_new ();
       mongoc_write_concern_set_w (wc, MONGOC_WRITE_CONCERN_W_MAJORITY);
       bulk_opts = bson_new ();
       mongoc_write_concern_append (wc, bulk_opts);
+      if (!mongoc_client_session_append (sess, bulk_opts, error)) {
+         goto loopexit;
+      }
 
       /* Drop the collection. */
       /* Check if the server supports majority write concern on 'drop' and
@@ -913,8 +920,15 @@ test_setup_initial_data (test_t *test, bson_error_t *error)
          BSON_APPEND_INT32 (drop_opts, "serverId", 1);
          BSON_APPEND_INT32 (create_opts, "serverId", 1);
       }
+      if (!mongoc_client_session_append (sess, create_opts, error)) {
+         goto loopexit;
+      }
+      if (!mongoc_client_session_append (sess, drop_opts, error)) {
+         goto loopexit;
+      }
 
       coll = mongoc_client_get_collection (test_runner->internal_client, database_name, collection_name);
+
       if (!mongoc_collection_drop_with_opts (coll, drop_opts, error)) {
          if (error->code != 26 && (NULL == strstr (error->message, "ns not found"))) {
             /* This is not a "ns not found" error. Fail the test. */
@@ -924,6 +938,52 @@ test_setup_initial_data (test_t *test, bson_error_t *error)
          memset (error, 0, sizeof (bson_error_t));
       }
 
+      // Drop `enxcol_.<coll>.esc` and `enxcol_.<coll>.ecoc` in case the collection will be used for QE.
+      // https://github.com/mongodb/specifications/blob/f4c0bbdbf8a8560580c947ca2c331794431a0c78/source/unified-test-format/unified-test-format.md#executing-a-test
+      {
+         char *collection_name_esc = bson_strdup_printf ("enxcol_.%s.esc", collection_name);
+         mongoc_collection_t *coll_esc =
+            mongoc_client_get_collection (test_runner->internal_client, database_name, collection_name_esc);
+         if (!mongoc_collection_drop_with_opts (coll_esc, drop_opts, error)) {
+            if (error->code != 26 && (NULL == strstr (error->message, "ns not found"))) {
+               /* This is not a "ns not found" error. Fail the test. */
+               mongoc_collection_destroy (coll_esc);
+               bson_free (collection_name_esc);
+               goto loopexit;
+            }
+            /* Clear an "ns not found" error. */
+            memset (error, 0, sizeof (bson_error_t));
+         }
+         mongoc_collection_destroy (coll_esc);
+         bson_free (collection_name_esc);
+      }
+
+      {
+         char *collection_name_ecoc = bson_strdup_printf ("enxcol_.%s.ecoc", collection_name);
+         mongoc_collection_t *coll_ecoc =
+            mongoc_client_get_collection (test_runner->internal_client, database_name, collection_name_ecoc);
+         if (!mongoc_collection_drop_with_opts (coll_ecoc, drop_opts, error)) {
+            if (error->code != 26 && (NULL == strstr (error->message, "ns not found"))) {
+               /* This is not a "ns not found" error. Fail the test. */
+               mongoc_collection_destroy (coll_ecoc);
+               bson_free (collection_name_ecoc);
+               goto loopexit;
+            }
+            /* Clear an "ns not found" error. */
+            memset (error, 0, sizeof (bson_error_t));
+         }
+         mongoc_collection_destroy (coll_ecoc);
+         bson_free (collection_name_ecoc);
+      }
+
+      mongoc_collection_t *new_coll = NULL;
+      db = mongoc_client_get_database (test_runner->internal_client, database_name);
+      new_coll = mongoc_database_create_collection (db, collection_name, create_opts, error);
+      if (!new_coll) {
+         goto loopexit;
+      }
+      mongoc_collection_destroy (new_coll);
+
       /* Insert documents if specified. */
       if (bson_count_keys (documents) > 0) {
          bson_iter_t documents_iter;
@@ -946,15 +1006,6 @@ test_setup_initial_data (test_t *test, bson_error_t *error)
          if (!mongoc_bulk_operation_execute (bulk_insert, NULL, error)) {
             goto loopexit;
          }
-      } else {
-         mongoc_collection_t *new_coll = NULL;
-         /* Test does not need data inserted, just create the collection. */
-         db = mongoc_client_get_database (test_runner->internal_client, database_name);
-         new_coll = mongoc_database_create_collection (db, collection_name, create_opts, error);
-         if (!new_coll) {
-            goto loopexit;
-         }
-         mongoc_collection_destroy (new_coll);
       }
 
       ret = true;
@@ -972,9 +1023,18 @@ test_setup_initial_data (test_t *test, bson_error_t *error)
       bson_parser_destroy (parser);
       mongoc_database_destroy (db);
       if (!ret) {
+         mongoc_client_session_destroy (sess);
          return false;
       }
    }
+
+   // Obtain cluster time to advance client sessions. See DRIVERS-2816.
+   // Check for cluster time (not available on standalone).
+   const bson_t *ct = mongoc_client_session_get_cluster_time (sess);
+   if (ct) {
+      test->cluster_time_after_initial_data = bson_copy (ct);
+   }
+   mongoc_client_session_destroy (sess);
    return true;
 }
 
@@ -1001,7 +1061,7 @@ test_create_entities (test_t *test, bson_error_t *error)
       bson_t entity_bson;
 
       bson_iter_bson (&iter, &entity_bson);
-      if (!entity_map_create (test->entity_map, &entity_bson, error)) {
+      if (!entity_map_create (test->entity_map, &entity_bson, test->cluster_time_after_initial_data, error)) {
          return false;
       }
    }
@@ -1291,6 +1351,24 @@ test_count_matching_events_for_client (
    return true;
 }
 
+// `is_keyvault_listcollections` returns true if a `listCollections` event produced by libmongoc should be ignored.
+// The extra events are caused by operations on the key vault collection. Unlike other drivers, libmongoc does not
+// create a separate client for key vault operations.
+static bool
+is_keyvault_listcollections (const bson_t *event)
+{
+   if (!bson_has_field (event, "commandName") || !bson_has_field (event, "databaseName")) {
+      return false;
+   }
+
+   const char *cmdname = bson_lookup_utf8 (event, "commandName");
+   const char *dbname = bson_lookup_utf8 (event, "databaseName");
+   if (cmdname && 0 == strcmp (cmdname, "listCollections") && dbname && 0 == strcmp (dbname, "keyvault")) {
+      return true;
+   }
+   return false;
+}
+
 static bool
 test_check_expected_events_for_client (test_t *test, bson_t *expected_events_for_client, bson_error_t *error)
 {
@@ -1335,6 +1413,10 @@ test_check_expected_events_for_client (test_t *test, bson_t *expected_events_for
    event_t *eiter;
    LL_FOREACH (entity->events, eiter)
    {
+      if (is_keyvault_listcollections (eiter->serialized)) {
+         // Ignore.
+         continue;
+      }
       if (event_matches_eventtype (eiter, event_type)) {
          actual_num_events++;
       }
@@ -1358,8 +1440,11 @@ test_check_expected_events_for_client (test_t *test, bson_t *expected_events_for
    bson_iter_t iter;
    BSON_FOREACH (expected_events, iter)
    {
-      while (eiter && !event_matches_eventtype (eiter, event_type)) {
+      while (eiter &&
+             (is_keyvault_listcollections (eiter->serialized) || !event_matches_eventtype (eiter, event_type))) {
+         // Skip.
          eiter = eiter->next;
+         continue;
       }
       bson_t expected_event;
       bson_iter_bson (&iter, &expected_event);
@@ -1368,7 +1453,11 @@ test_check_expected_events_for_client (test_t *test, bson_t *expected_events_for
          goto done;
       }
       if (!test_check_event (test, &expected_event, eiter, error)) {
-         test_diagnostics_error_info ("checking for expected event: %s", tmp_json (&expected_event));
+         test_diagnostics_error_info ("could not match event\n"
+                                      "\texpected: %s\n"
+                                      "\tactual: %s",
+                                      tmp_json (&expected_event),
+                                      tmp_json (eiter->serialized));
          goto done;
       }
       eiter = eiter->next;
@@ -1516,7 +1605,7 @@ test_check_log_message (bson_t *expected, log_message_t *actual, bson_error_t *e
       if (!bson_iter_init_find (&failure_iter, actual->message, "failure")) {
          test_set_error (error, "expected log 'failure' to exist");
          goto done;
-      };
+      }
       if (*failure_is_redacted) {
          if (!check_failure_is_redacted (&failure_iter, error)) {
             test_diagnostics_error_info ("actual log message: %s", tmp_json (actual->message));
@@ -1814,111 +1903,6 @@ done:
    return ret;
 }
 
-static void
-append_size_t (bson_t *doc, const char *key, size_t value)
-{
-   BSON_ASSERT (mlib_in_range (int64_t, value));
-   BSON_ASSERT (BSON_APPEND_INT64 (doc, key, (int64_t) value));
-}
-
-static void
-append_bson_array (bson_t *doc, const char *key, const mongoc_array_t *array)
-{
-   BSON_ASSERT_PARAM (key);
-   BSON_OPTIONAL_PARAM (array);
-
-   if (!array) {
-      bson_t empty = BSON_INITIALIZER;
-      BSON_ASSERT (BSON_APPEND_ARRAY (doc, key, &empty));
-      bson_destroy (&empty);
-   } else {
-      bson_t **const begin = array->data;
-      bson_t **const end = begin + array->len;
-
-      bson_array_builder_t *elements;
-
-      BSON_ASSERT (BSON_APPEND_ARRAY_BUILDER_BEGIN (doc, key, &elements));
-      for (bson_t **iter = begin; iter != end; ++iter) {
-         BSON_ASSERT (bson_array_builder_append_document (elements, *iter));
-      }
-      BSON_ASSERT (bson_append_array_builder_end (doc, elements));
-   }
-}
-
-static bool
-test_generate_atlas_results (test_t *test, bson_error_t *error)
-{
-   BSON_ASSERT_PARAM (test);
-   BSON_ASSERT_PARAM (error);
-
-   // This is only applicable when the unified test runner is being run by
-   // test-atlas-executor. Must be implemented within unified test runner in
-   // order to capture entities before destruction of parent test object.
-   if (!test_framework_getenv_bool ("MONGOC_TEST_ATLAS")) {
-      return true;
-   }
-
-   MONGOC_DEBUG ("generating events.json and results.json files...");
-
-   size_t *const iterations = entity_map_get_size_t (test->entity_map, "iterations", NULL);
-   size_t *const successes = entity_map_get_size_t (test->entity_map, "successes", NULL);
-   mongoc_array_t *const errors = entity_map_get_bson_array (test->entity_map, "errors", NULL);
-   mongoc_array_t *const failures = entity_map_get_bson_array (test->entity_map, "failures", NULL);
-   mongoc_array_t *const events = entity_map_get_bson_array (test->entity_map, "events", NULL);
-
-   bson_t events_doc = BSON_INITIALIZER;
-   bson_t results_doc = BSON_INITIALIZER;
-
-   append_bson_array (&events_doc, "events", events);
-   append_bson_array (&events_doc, "failures", failures);
-   append_bson_array (&events_doc, "errors", errors);
-
-   append_size_t (&results_doc, "numErrors", errors ? errors->len : 0u);
-   append_size_t (&results_doc, "numFailures", failures ? failures->len : 0u);
-   append_size_t (&results_doc, "numIterations", iterations ? *iterations : 0u);
-   append_size_t (&results_doc, "numSuccesses", successes ? *successes : 0u);
-
-#ifdef WIN32
-   const int perms = _S_IWRITE;
-#else
-   const int perms = S_IRWXU;
-#endif
-
-   mongoc_stream_t *const events_file =
-      mongoc_stream_file_new_for_path ("events.json", O_CREAT | O_WRONLY | O_TRUNC, perms);
-   ASSERT_WITH_MSG (events_file, "could not open events.json");
-
-   mongoc_stream_t *const results_file =
-      mongoc_stream_file_new_for_path ("results.json", O_CREAT | O_WRONLY | O_TRUNC, perms);
-   ASSERT_WITH_MSG (results_file, "could not open results.json");
-
-   size_t events_json_len = 0u;
-   size_t results_json_len = 0u;
-   char *const events_json = bson_as_relaxed_extended_json (&events_doc, &events_json_len);
-   char *const results_json = bson_as_relaxed_extended_json (&results_doc, &results_json_len);
-
-   ASSERT_WITH_MSG (events_json, "failed to convert events BSON document to JSON");
-   ASSERT_WITH_MSG (results_json, "failed to convert results BSON document to JSON");
-
-   ASSERT_WITH_MSG (mongoc_stream_write (events_file, events_json, events_json_len, 500) > 0,
-                    "failed to write events to events.json");
-   ASSERT_WITH_MSG (mongoc_stream_write (results_file, results_json, results_json_len, 500) > 0,
-                    "failed to write results to results.json");
-
-   bson_free (events_json);
-   bson_free (results_json);
-
-   mongoc_stream_destroy (events_file);
-   mongoc_stream_destroy (results_file);
-
-   bson_destroy (&events_doc);
-   bson_destroy (&results_doc);
-
-   MONGOC_DEBUG ("generating events.json and results.json files... done.");
-
-   return true;
-}
-
 static bool
 run_distinct_on_each_mongos (test_t *test, char *db_name, char *coll_name, bson_error_t *error)
 {
@@ -2106,11 +2090,6 @@ test_run (test_t *test, bson_error_t *error)
       goto done;
    }
 
-   if (!test_generate_atlas_results (test, error)) {
-      test_diagnostics_error_info ("%s", "generating Atlas test results");
-      goto done;
-   }
-
    ret = true;
 done:
    /* always clean up failpoints, even on test failure */
